openapi: 3.0.0
info:
  title: Barikoi Business API
  license:
    name: Barikoi
    url: https://www.barikoi.com/
  description: >

    # Introduction

    Welcome to Barikoi API. Thank you for checking a Bangladeshi location data
    provider API. Our API helps you to find address, geocode and reverse geocode
    place and city corporation information in Dhaka in our local context.

      <h3>Overview</h3>

      The currently listed places API's are for autocomplete, post office autocomplete, geocoding, reverse geocoding, nearby, distance & rupantor geocoder. And City Corporation API's are Ward by Geolocation, Zone by Geolocation, Ward and Zone by Geolocation, City Corporation by Geolocation services.

    # Get started

    To access our APIs you will need an API key. Generating an API key is easy.
    You just need to [Sign Up](https://developer.barikoi.com/register) and
    select your desired package. With our api key you are now ready to use our
    Bkoigl js data and map.


    Each API part has its own documentation. Jump to the desired API part and
    learn about the API through the given examples and tutorials.

    <br/> <br/> <br/>

      ### Version 2
      * [Reverse Geocoding](#tag/v2.0/operation/revgeo_v2)
      * [Autocomplete](#tag/v2.0/operation/autocomplete_v2)
      * [Rupantor Geocoder](#tag/v2.0/operation/rupantor_geocoder_v2)
      * [Rupantor Address Match](#tag/v2.0/operation/rupantor_address_match_v2)
      * [Route Location Optimized](#tag/v2.0/operation/route_location_optimized)
      * [Route Match](#tag/v2.0/operation/route_match_v2)
      * [Area](#tag/v2.0/operation/area_v2)
      * [Ward Geometry](#tag/v2.0/operation/ward_v2)
      * [Nearby API with Query Param](#tag/v2.0/operation/nearby_query_param)
      * [Point in Polygon](#tag/v2.0/operation/point-in-polygon_v2)



      <br/>
      <br/>
      <br/>

      ### Version 1 

      > #### Version 1 will be depricated after 31/10/2023, therefore it is strongly advised for everyone to switch to   version 2.
      
      * [Reverse Geocode](#tag/v1.0/operation/revgeo_v1)
      * [Reverse Geocoding (Server)](#tag/v1.0/operation/revgeo_server_v1)
      * [Autocomplete](#tag/v1.0/operation/autocomplete_v1)
      * [Distance](#tag/v1.0/operation/distance_v1)
      * [Rupantor Geocoder](#tag/v1.0/operation/rupantor_geocoder_v1)
      * [Rupantor Address Match](#tag/v1.0/operation/rupantor_address_match_v1)
      * [Routing](#tag/v1.0/operation/routing_v1)
      * [Snap To Road](#tag/v1.0/operation/snap_to_road_v1)
      * [Route Match](#tag/v1.0/operation/route_match_v1)
      * [Districts](#tag/v1.0/operation/districts_v1)
      * [Sub Districts](#tag/v1.0/operation/sub_districts_v1)
      * [Cities](#tag/v1.0/operation/cities_v1)
      * [Unions](#tag/v1.0/operation/unions_v1)
      * [Ward by Geolocation](#tag/v1.0/operation/ward_v1)
      * [Zone by Geolocation](#tag/v1.0/operation/zone_v1)
      * [Ward Zone by Geolocation](#tag/v1.0/operation/ward_zone_v1)
      * [City Corporation by Geolocation](#tag/v1.0/operation/dncc_v1)

    # Contact Us
     For any query or tech support please mail at support@barikoi.com
  termsOfService: https://www.barikoi.com/data-privacy
  contact:
    name: API Support
    email: hello@barikoi.com
    url: https://www.barikoi.com/
  x-logo:
    url: barikoi.png
    altText: Barikoi
tags:
  - name: v2.0
    description: Version 2.0 Endpoints
  - name: v1.0
    description: Version 1.0 Endpoints
servers:
  - url: https://barikoi.xyz
    description: Barikoi API Server
security:
  - api_key: []
paths:
  /v1/api/search/reverse/{api_key}/geocode:
    get:
      operationId: revgeo_v1
      tags:
        - v1.0
      summary: Reverse Geocoding
      description: >-
        This API initially returns id, address, area, city,
        distance_within_meters without any additional call
      parameters:
        - $ref: '#/components/parameters/api_key_path'
        - $ref: '#/components/parameters/longitude'
        - $ref: '#/components/parameters/latitude'
        - $ref: '#/components/parameters/district'
        - $ref: '#/components/parameters/post_code'
        - $ref: '#/components/parameters/country'
        - $ref: '#/components/parameters/sub_district'
        - $ref: '#/components/parameters/union'
        - $ref: '#/components/parameters/pauroshova'
        - $ref: '#/components/parameters/location_type'
        - $ref: '#/components/parameters/division'
        - $ref: '#/components/parameters/address'
        - $ref: '#/components/parameters/area'
        - $ref: '#/components/parameters/bangla'
      x-code-samples:
        - lang: Curl
          source: >
            curl --location
            'https://barikoi.xyz/v1/api/search/reverse/API_KEY/geocode?longitude=90.36744611263278&latitude=23.81970957278533&district=true&post_code=true&country=true&sub_district=true&union=true&pauroshova=true&location_type=true&division=true&address=true&area=true&bangla=true'
        - lang: Python
          source: >
            import requests

            url =
            "https://barikoi.xyz/v1/api/search/reverse/API_KEY/geocode?longitude=90.36744611263278&latitude=23.81970957278533&district=true&post_code=true&country=true&sub_district=true&union=true&pauroshova=true&location_type=true&division=true&address=true&area=true&bangla=true"

            payload={}

            headers = {}

            response = requests.request("GET", url, headers=headers,
            data=payload)

            print(response.text)
        - lang: Node
          source: |
            var axios = require('axios');
            var config = {
              method: 'get',
              maxBodyLength: Infinity,
              url: 'https://barikoi.xyz/v1/api/search/reverse/API_KEY/geocode?longitude=90.36744611263278&latitude=23.81970957278533&district=true&post_code=true&country=true&sub_district=true&union=true&pauroshova=true&location_type=true&division=true&address=true&area=true&bangla=true',
              headers: { }
            };
            axios(config)
            .then(function (response) {
              console.log(JSON.stringify(response.data));
            })
            .catch(function (error) {
              console.log(error);
            });
      responses:
        '200':
          $ref: '#/components/responses/rev_geo_success'
        '400':
          $ref: '#/components/responses/missing_parameter'
        '401':
          $ref: '#/components/responses/no_registered_key'
        '402':
          $ref: '#/components/responses/payment_exception'
        '429':
          $ref: '#/components/responses/api_limit_exceeded'
  /v1/api/search/reverse/geocode/server/{api_key}/place:
    get:
      operationId: revgeo_server_v1
      tags:
        - v1.0
      summary: Reverse Geocoding Server
      description: >-
        This API initially returns id, address, area, city,
        distance_within_meters without any additional call
      parameters:
        - $ref: '#/components/parameters/api_key_path'
        - $ref: '#/components/parameters/longitude'
        - $ref: '#/components/parameters/latitude'
        - $ref: '#/components/parameters/district'
        - $ref: '#/components/parameters/post_code'
        - $ref: '#/components/parameters/country'
        - $ref: '#/components/parameters/sub_district'
        - $ref: '#/components/parameters/union'
        - $ref: '#/components/parameters/pauroshova'
        - $ref: '#/components/parameters/location_type'
        - $ref: '#/components/parameters/division'
        - $ref: '#/components/parameters/address'
        - $ref: '#/components/parameters/area'
      x-code-samples:
        - lang: Curl
          source: >
            curl --location
            'https://barikoi.xyz/v1/api/search/reverse/geocode/server/API_KEY/place?longitude=90.36744611263278&latitude=23.81970957278533&district=true&post_code=true&country=true&sub_district=true&union=true&pauroshova=true&location_type=true&division=true&address=true&area=true'
        - lang: Python
          source: >
            import requests

            url =
            "https://barikoi.xyz/v1/api/search/reverse/geocode/server/API_KEY/place?longitude=90.36744611263278&latitude=23.81970957278533&district=true&post_code=true&country=true&sub_district=true&union=true&pauroshova=true&location_type=true&division=true&address=true&area=true"

            payload={}

            headers = {}

            response = requests.request("GET", url, headers=headers,
            data=payload)

            print(response.text)
        - lang: Node
          source: |
            var axios = require('axios');
            var config = {
              method: 'get',
              maxBodyLength: Infinity,
              url: 'https://barikoi.xyz/v1/api/search/reverse/geocode/server/API_KEY/place?longitude=90.36744611263278&latitude=23.81970957278533&district=true&post_code=true&country=true&sub_district=true&union=true&pauroshova=true&location_type=true&division=true&address=true&area=true',
              headers: { }
            };
            axios(config)
            .then(function (response) {
              console.log(JSON.stringify(response.data));
            })
            .catch(function (error) {
              console.log(error);
            });
      responses:
        '200':
          $ref: '#/components/responses/rev_geo_server_success'
        '400':
          $ref: '#/components/responses/missing_parameter'
        '401':
          $ref: '#/components/responses/no_registered_key'
        '402':
          $ref: '#/components/responses/payment_exception'
        '429':
          $ref: '#/components/responses/api_limit_exceeded'
  /v1/api/search/autocomplete/{api_key}/place:
    get:
      operationId: autocomplete_v1
      tags:
        - v1.0
      summary: AutoComplete
      description: >-
        Barikoi Autocomplete return's a place's id, longitude, latitude,
        address, city, area, postCode, pType & uCode
      parameters:
        - $ref: '#/components/parameters/api_key_path'
        - $ref: '#/components/parameters/q'
        - $ref: '#/components/parameters/city'
        - $ref: '#/components/parameters/post_office'
        - $ref: '#/components/parameters/industrial'
        - $ref: '#/components/parameters/bangla'
      x-code-samples:
        - lang: Curl
          source: >
            curl --location
            'https://barikoi.xyz/v1/api/search/autocomplete/API_KEY/place?q=nabisco&city=dhaka&post_office=true&industrial=true&bangla=true'
        - lang: Python
          source: >
            import requests

            url =
            "https://barikoi.xyz/v1/api/search/autocomplete/API_KEY/place?q=nabisco&city=dhaka&post_office=true&industrial=true&bangla=true"

            payload={}

            headers = {}

            response = requests.request("GET", url, headers=headers,
            data=payload)

            print(response.text)
        - lang: Node
          source: |
            var axios = require('axios');
            var config = {
              method: 'get',
            maxBodyLength: Infinity,
              url: 'https://barikoi.xyz/v1/api/search/autocomplete/API_KEY/place?q=nabisco&city=dhaka&post_office=true&industrial=true&bangla=true',
              headers: { }
            };
            axios(config)
            .then(function (response) {
              console.log(JSON.stringify(response.data));
            })
            .catch(function (error) {
              console.log(error);
            });
      responses:
        '200':
          $ref: '#/components/responses/autocomplete_success'
        '400':
          $ref: '#/components/responses/missing_parameter'
        '401':
          $ref: '#/components/responses/no_registered_key'
        '402':
          $ref: '#/components/responses/payment_exception'
        '429':
          $ref: '#/components/responses/api_limit_exceeded'
  /v1/api/distance/{api_key}/{longitude},{latitude}/{longitude},{latitude}:
    get:
      operationId: distance_v1
      tags:
        - v1.0
      summary: Distance
      parameters:
        - $ref: '#/components/parameters/api_key_path'
        - $ref: '#/components/parameters/longitudePath'
        - $ref: '#/components/parameters/latitudePath'
      x-code-samples:
        - lang: Curl
          source: >
            curl --location
            'https://barikoi.xyz/v1/api/distance/API_KEY/90.357238,23.806672/90.357252,23.811626'
        - lang: Python
          source: >
            import requests

            url =
            "https://barikoi.xyz/v1/api/distance/API_KEY/90.357238,23.806672/90.357252,23.811626"

            payload={}

            headers = {}

            response = requests.request("GET", url, headers=headers,
            data=payload)

            print(response.text)
        - lang: Node
          source: |
            var axios = require('axios');
            var config = {
              method: 'get',
              maxBodyLength: Infinity,
              url: 'https://barikoi.xyz/v1/api/distance/API_KEY/90.357238,23.806672/90.357252,23.811626',
              headers: { }
            };
            axios(config)
            .then(function (response) {
              console.log(JSON.stringify(response.data));
            })
            .catch(function (error) {
              console.log(error);
            });
      responses:
        '200':
          $ref: '#/components/responses/distance_success'
        '400':
          $ref: '#/components/responses/missing_parameter'
        '401':
          $ref: '#/components/responses/no_registered_key'
        '402':
          $ref: '#/components/responses/payment_exception'
        '429':
          $ref: '#/components/responses/api_limit_exceeded'
  /v1/api/search/{API_KEY}/rupantor/geocode:
    post:
      operationId: rupantor_geocoder_v1
      tags:
        - v1.0
      summary: Rupantor Geocoder
      description: >-
        Rupantor Geocoder API for Developers. It formats the given address and
        searches for the address and gives a status if the address is complete
        or not. Rupantor Geocoder only supports FormData. So use FormData object
        to send your data. Rupantor Geocoder needs Geocode API to fucntion
        properly. One Rupantor Geocoder request requires two Geocode API
        requests.
      parameters:
        - $ref: '#/components/parameters/api_key_path_upper'
      x-code-samples:
        - lang: Curl
          source: >
            curl --location
            'https://barikoi.xyz/v1/api/search/API_KEY/rupantor/geocode' \

            --form 'q="matikata rd basa 572/k barikoi"' \

            --form 'thana="yes"' \

            --form 'district="yes"' \

            --form 'bangla="yes"'
        - lang: Python
          source: >
            import requests

            url = "https://barikoi.xyz/v1/api/search/API_KEY/rupantor/geocode"

            payload={'q': 'matikata rd basa 572/k barikoi',

            'thana': 'yes',

            'district': 'yes',

            'bangla': 'yes'}

            files=[]

            headers = {}

            response = requests.request("POST", url, headers=headers,
            data=payload, files=files)

            print(response.text)
        - lang: Node
          source: |
            var axios = require('axios');
            var FormData = require('form-data');
            var data = new FormData();
            data.append('q', 'matikata rd basa 572/k barikoi');
            data.append('thana', 'yes');
            data.append('district', 'yes');
            data.append('bangla', 'yes');
            var config = {
              method: 'post',
              maxBodyLength: Infinity,
              url: 'https://barikoi.xyz/v1/api/search/API_KEY/rupantor/geocode',
              headers: { 
                ...data.getHeaders()
              },
              data : data
            };
            axios(config)
            .then(function (response) {
              console.log(JSON.stringify(response.data));
            })
            .catch(function (error) {
              console.log(error);
            });
      requestBody:
        required: true
        content:
          application/x-www-form-urlencoded:
            schema:
              $ref: '#/components/schemas/rupantor_geocoder_form_v1'
      responses:
        '200':
          $ref: '#/components/responses/rupantor_geocoder_success'
        '400':
          $ref: '#/components/responses/missing_parameter'
        '401':
          $ref: '#/components/responses/no_registered_key'
        '402':
          $ref: '#/components/responses/payment_exception'
        '429':
          $ref: '#/components/responses/api_limit_exceeded'
  /v1/api/search/{api_key}/rupantor/geocode:
    post:
      operationId: rupantor_address_match_v1
      tags:
        - v1.0
      summary: Rupantor Address Match
      description: >-
        Rupantor Address Matcher API matches two different given address and
        returns match percantage and match status.
      parameters:
        - $ref: '#/components/parameters/api_key_path'
      x-code-samples:
        - lang: Curl
          source: >
            curl --location
            'https://barikoi.xyz/v1/api/search/API_KEY/rupantor/geocode' \

            --form 'q="হাউস ১৮, রোড ৫, ব্লক জি, সেকশন ২ মিরপুর"' \

            --form 'q2="house 18, road 5, block G, section 2, mirpur"' \

            --form 'match="yes"'
        - lang: Python
          source: >
            import requests

            url = "https://barikoi.xyz/v1/api/search/API_KEY/rupantor/geocode"

            payload={'q': 'হাউস ১৮, রোড ৫, ব্লক জি, সেকশন ২ মিরপুর',

            'q2': 'house 18, road 5, block G, section 2, mirpur',

            'match': 'yes'}

            files=[]

            headers = {}

            response = requests.request("POST", url, headers=headers,
            data=payload, files=files)

            print(response.text)
        - lang: Node
          source: |
            var axios = require('axios');
            var FormData = require('form-data');
            var data = new FormData();
            data.append('q', 'হাউস ১৮, রোড ৫, ব্লক জি, সেকশন ২ মিরপুর');
            data.append('q2', 'house 18, road 5, block G, section 2, mirpur');
            data.append('match', 'yes');
            var config = {
              method: 'post',
              maxBodyLength: Infinity,
              url: 'https://barikoi.xyz/v1/api/search/API_KEY/rupantor/geocode',
              headers: { 
                ...data.getHeaders()
              },
              data : data
            };
            axios(config)
            .then(function (response) {
              console.log(JSON.stringify(response.data));
            })
            .catch(function (error) {
              console.log(error);
            });
      requestBody:
        required: true
        content:
          application/x-www-form-urlencoded:
            schema:
              $ref: '#/components/schemas/rupantor_address_match_form'
      responses:
        '200':
          $ref: '#/components/responses/rupantor_address_match_success'
        '400':
          $ref: '#/components/responses/missing_parameter'
        '401':
          $ref: '#/components/responses/no_registered_key'
        '402':
          $ref: '#/components/responses/payment_exception'
        '429':
          $ref: '#/components/responses/api_limit_exceeded'
  /v1/api/route/{api_key}/{coordinates}:
    get:
      operationId: routing_v1
      tags:
        - v1.0
      summary: Routing
      description: This api provides routing details for two location points.
      parameters:
        - $ref: '#/components/parameters/api_key_path'
        - $ref: '#/components/parameters/coordinates'
      x-code-samples:
        - lang: Curl
          source: >
            curl --location
            'https://barikoi.xyz/v1/api/route/API_KEY/90.362548828125,23.94107556246209;90.31585693359375,24.134221690669204'
        - lang: Python
          source: >
            import requests

            url =
            "https://barikoi.xyz/v1/api/route/API_KEY/90.362548828125,23.94107556246209;90.31585693359375,24.134221690669204"

            payload={}

            headers = {}

            response = requests.request("GET", url, headers=headers,
            data=payload)

            print(response.text)
        - lang: Node
          source: |
            var axios = require('axios');
            var config = {
              method: 'get',
              maxBodyLength: Infinity,
              url: 'https://barikoi.xyz/v1/api/route/API_KEY/90.362548828125,23.94107556246209;90.31585693359375,24.134221690669204',
              headers: { }
            };
            axios(config)
            .then(function (response) {
              console.log(JSON.stringify(response.data));
            })
            .catch(function (error) {
              console.log(error);
            });
      responses:
        '200':
          $ref: '#/components/responses/routing_success'
        '400':
          $ref: '#/components/responses/missing_parameter'
        '401':
          $ref: '#/components/responses/no_registered_key'
        '402':
          $ref: '#/components/responses/payment_exception'
        '429':
          $ref: '#/components/responses/api_limit_exceeded'
  /v1/api/routing/{api_key}/nearest:
    get:
      operationId: snap_to_road_v1
      tags:
        - v1.0
      summary: Snap to Road
      description: ' '
      parameters:
        - $ref: '#/components/parameters/api_key_path'
        - $ref: '#/components/parameters/point'
      x-code-samples:
        - lang: Curl
          source: >
            curl --location
            'https://barikoi.xyz/v1/api/routing/API_KEY/matching?points=90.38436119310136,23.7267599142696%3B90.38438265469962,23.726622279057658'
        - lang: Python
          source: >
            import requests

            url =
            "https://barikoi.xyz/v1/api/routing/API_KEY/nearest?point=23.80474653651567,90.36288913339376"

            payload={}

            headers = {}

            response = requests.request("GET", url, headers=headers,
            data=payload)

            print(response.text)
        - lang: Node
          source: |
            var axios = require('axios');
            var config = {
              method: 'get',
              maxBodyLength: Infinity,
              url: 'https://barikoi.xyz/v1/api/routing/API_KEY/nearest?point=23.80474653651567,90.36288913339376',
              headers: { }
            };
            axios(config)
            .then(function (response) {
              console.log(JSON.stringify(response.data));
            })
            .catch(function (error) {
              console.log(error);
            });
      responses:
        '200':
          $ref: '#/components/responses/span_to_road_success'
        '400':
          $ref: '#/components/responses/missing_parameter'
        '401':
          $ref: '#/components/responses/no_registered_key'
        '402':
          $ref: '#/components/responses/payment_exception'
        '429':
          $ref: '#/components/responses/api_limit_exceeded'
  /v1/api/routing/{api_key}/matching:
    get:
      operationId: route_match_v1
      tags:
        - v1.0
      summary: Route match
      parameters:
        - $ref: '#/components/parameters/api_key_path'
        - $ref: '#/components/parameters/points'
      x-code-samples:
        - lang: Curl
          source: >
            curl --location
            'https://barikoi.xyz/v1/api/routing/API_KEY/matching?points=90.38436119310136,23.7267599142696%3B90.38438265469962,23.726622279057658'
        - lang: Python
          source: >
            import requests

            url =
            "https://barikoi.xyz/v1/api/routing/API_KEY/matching?points=90.38436119310136,23.7267599142696;90.38438265469962,23.726622279057658"

            payload={}

            headers = {}

            response = requests.request("GET", url, headers=headers,
            data=payload)

            print(response.text)
        - lang: Node
          source: |
            var axios = require('axios');
            var config = {
              method: 'get',
            maxBodyLength: Infinity,
              url: 'https://barikoi.xyz/v1/api/routing/API_KEY/matching?points=90.38436119310136,23.7267599142696;90.38438265469962,23.726622279057658',
              headers: { }
            };  
            axios(config)
            .then(function (response) {
              console.log(JSON.stringify(response.data));
            })
            .catch(function (error) {
              console.log(error);
            });
      responses:
        '200':
          $ref: '#/components/responses/route_match_success'
        '400':
          $ref: '#/components/responses/missing_parameter'
        '401':
          $ref: '#/components/responses/no_registered_key'
        '402':
          $ref: '#/components/responses/payment_exception'
        '429':
          $ref: '#/components/responses/api_limit_exceeded'
  /v1/api/{api_key}/districts:
    get:
      operationId: districts_v1
      tags:
        - v1.0
      summary: Districts
      parameters:
        - $ref: '#/components/parameters/api_key_path'
        - $ref: '#/components/parameters/q_districts'
      x-code-samples:
        - lang: Curl
          source: >
            curl --location
            'https://barikoi.xyz/v1/api/API_KEY/districts?q=Dhaka'
        - lang: Python
          source: >
            import requests

            url = "https://barikoi.xyz/v1/api/API_KEY/districts?q=Dhaka"

            payload={}

            headers = {}

            response = requests.request("GET", url, headers=headers,
            data=payload)

            print(response.text)
        - lang: Node
          source: |
            var axios = require('axios');

            var config = {
              method: 'get',
            maxBodyLength: Infinity,
              url: 'https://barikoi.xyz/v1/api/API_KEY/districts?q=Dhaka',
              headers: { }
            };

            axios(config)
            .then(function (response) {
              console.log(JSON.stringify(response.data));
            })
            .catch(function (error) {
              console.log(error);
            });
      responses:
        '200':
          $ref: '#/components/responses/districts_success'
        '400':
          $ref: '#/components/responses/missing_parameter'
        '401':
          $ref: '#/components/responses/no_registered_key'
        '402':
          $ref: '#/components/responses/payment_exception'
        '429':
          $ref: '#/components/responses/api_limit_exceeded'
  /v1/api/{api_key}/sub_districts:
    get:
      operationId: sub_districts_v1
      tags:
        - v1.0
      summary: Subdistricts
      parameters:
        - $ref: '#/components/parameters/api_key_path'
        - $ref: '#/components/parameters/q_subdistricts'
      x-code-samples:
        - lang: Curl
          source: >
            curl --location
            'https://barikoi.xyz/v1/api/API_KEY/sub_districts?q=Khilgaon'
        - lang: Python
          source: >
            import requests

            url = "https://barikoi.xyz/v1/api/API_KEY/sub_districts?q=Khilgaon"

            payload={}

            headers = {}

            response = requests.request("GET", url, headers=headers,
            data=payload)

            print(response.text)
        - lang: Node
          source: |
            var axios = require('axios');

            var config = {
              method: 'get',
            maxBodyLength: Infinity,
              url: 'https://barikoi.xyz/v1/api/API_KEY/sub_districts?q=Khilgaon',
              headers: { }
            };

            axios(config)
            .then(function (response) {
              console.log(JSON.stringify(response.data));
            })
            .catch(function (error) {
              console.log(error);
            });
      responses:
        '200':
          $ref: '#/components/responses/subdistricts_success'
        '400':
          $ref: '#/components/responses/missing_parameter'
        '401':
          $ref: '#/components/responses/no_registered_key'
        '402':
          $ref: '#/components/responses/payment_exception'
        '429':
          $ref: '#/components/responses/api_limit_exceeded'
  /v1/api/{api_key}/cities:
    get:
      operationId: cities_v1
      tags:
        - v1.0
      summary: Cities
      parameters:
        - $ref: '#/components/parameters/api_key_path'
        - $ref: '#/components/parameters/q_cities'
      x-code-samples:
        - lang: Curl
          source: |
            curl --location 'https://barikoi.xyz/v1/api/API_KEY/cities?q=Dhaka'
        - lang: Python
          source: >
            import requests

            url = "https://barikoi.xyz/v1/api/API_KEY/cities?q=Dhaka"

            payload={}

            headers = {}

            response = requests.request("GET", url, headers=headers,
            data=payload)

            print(response.text)
        - lang: Node
          source: |
            var axios = require('axios');

            var config = {
              method: 'get',
            maxBodyLength: Infinity,
              url: 'https://barikoi.xyz/v1/api/API_KEY/cities?q=Dhaka',
              headers: { }
            };

            axios(config)
            .then(function (response) {
              console.log(JSON.stringify(response.data));
            })
            .catch(function (error) {
              console.log(error);
            });
      responses:
        '200':
          $ref: '#/components/responses/cities_success'
        '400':
          $ref: '#/components/responses/missing_parameter'
        '401':
          $ref: '#/components/responses/no_registered_key'
        '402':
          $ref: '#/components/responses/payment_exception'
        '429':
          $ref: '#/components/responses/api_limit_exceeded'
  /v1/api/{api_key}/unions:
    get:
      operationId: unions_v1
      tags:
        - v1.0
      summary: Unions
      parameters:
        - $ref: '#/components/parameters/api_key_path'
        - $ref: '#/components/parameters/q_unions'
      x-code-samples:
        - lang: Curl
          source: >
            curl --location
            'https://barikoi.xyz/v1/api/API_KEY/unions?q=Abaipur'
        - lang: Python
          source: >
            import requests

            url = "https://barikoi.xyz/v1/api/API_KEY/unions?q=Abaipur"

            payload={}

            headers = {}

            response = requests.request("GET", url, headers=headers,
            data=payload)

            print(response.text)
        - lang: Node
          source: |
            var axios = require('axios');

            var config = {
              method: 'get',
            maxBodyLength: Infinity,
              url: 'https://barikoi.xyz/v1/api/API_KEY/unions?q=Abaipur',
              headers: { }
            };

            axios(config)
            .then(function (response) {
              console.log(JSON.stringify(response.data));
            })
            .catch(function (error) {
              console.log(error);
            });
      responses:
        '200':
          $ref: '#/components/responses/unions_success'
        '400':
          $ref: '#/components/responses/missing_parameter'
        '401':
          $ref: '#/components/responses/no_registered_key'
        '402':
          $ref: '#/components/responses/payment_exception'
        '429':
          $ref: '#/components/responses/api_limit_exceeded'
  /v1/api/search/ward/{api_key}/{longitude}/{latitude}:
    get:
      operationId: ward_v1
      tags:
        - v1.0
      summary: Ward by Geolocation
      parameters:
        - $ref: '#/components/parameters/api_key_path'
        - $ref: '#/components/parameters/longitudePath'
        - $ref: '#/components/parameters/latitudePath'
      x-code-samples:
        - lang: Curl
          source: >
            curl --location
            'https://barikoi.xyz/v1/api/search/ward/API_KEY/90.357238/23.806672'
        - lang: Python
          source: >
            import requests

            url =
            "https://barikoi.xyz/v1/api/search/ward/API_KEY/90.357238/23.806672"

            payload={}

            headers = {}

            response = requests.request("GET", url, headers=headers,
            data=payload)

            print(response.text)
        - lang: Node
          source: |
            var axios = require('axios');

            var config = {
              method: 'get',
            maxBodyLength: Infinity,
              url: 'https://barikoi.xyz/v1/api/search/ward/API_KEY/90.357238/23.806672',
              headers: { }
            };

            axios(config)
            .then(function (response) {
              console.log(JSON.stringify(response.data));
            })
            .catch(function (error) {
              console.log(error);
            });
      responses:
        '200':
          $ref: '#/components/responses/ward_success'
        '400':
          $ref: '#/components/responses/missing_parameter'
        '401':
          $ref: '#/components/responses/no_registered_key'
        '402':
          $ref: '#/components/responses/payment_exception'
        '429':
          $ref: '#/components/responses/api_limit_exceeded'
  /v1/api/search/zone/{api_key}/{longitude}/{latitude}:
    get:
      operationId: zone_v1
      tags:
        - v1.0
      summary: Zone by Geolocation
      parameters:
        - $ref: '#/components/parameters/api_key_path'
        - $ref: '#/components/parameters/longitudePath'
        - $ref: '#/components/parameters/latitudePath'
      x-code-samples:
        - lang: Curl
          source: >
            curl --location
            'https://barikoi.xyz/v1/api/search/zone/API_KEY/90.357238/23.806672'
        - lang: Python
          source: >
            import requests

            url =
            "https://barikoi.xyz/v1/api/search/zone/API_KEY/90.357238/23.806672"

            payload={}

            headers = {}

            response = requests.request("GET", url, headers=headers,
            data=payload)

            print(response.text)
        - lang: Node
          source: |
            var axios = require('axios');

            var config = {
              method: 'get',
            maxBodyLength: Infinity,
              url: 'https://barikoi.xyz/v1/api/search/zone/API_KEY/90.357238/23.806672',
              headers: { }
            };

            axios(config)
            .then(function (response) {
              console.log(JSON.stringify(response.data));
            })
            .catch(function (error) {
              console.log(error);
            });
      responses:
        '200':
          $ref: '#/components/responses/zone_success'
        '400':
          $ref: '#/components/responses/missing_parameter'
        '401':
          $ref: '#/components/responses/no_registered_key'
        '402':
          $ref: '#/components/responses/payment_exception'
        '429':
          $ref: '#/components/responses/api_limit_exceeded'
  /v1/api/search/ward/zone/{api_key}/{longitude}/{latitude}:
    get:
      operationId: ward_zone_v1
      tags:
        - v1.0
      summary: Ward Zone by Geolocation
      parameters:
        - $ref: '#/components/parameters/api_key_path'
        - $ref: '#/components/parameters/longitudePath'
        - $ref: '#/components/parameters/latitudePath'
      x-code-samples:
        - lang: Curl
          source: >
            curl --location
            'https://barikoi.xyz/v1/api/search/ward/zone/API_KEY/90.357238/23.806672'
        - lang: Python
          source: >
            import requests

            url =
            "https://barikoi.xyz/v1/api/search/ward/zone/API_KEY/90.357238/23.806672"

            payload={}

            headers = {}

            response = requests.request("GET", url, headers=headers,
            data=payload)

            print(response.text)
        - lang: Node
          source: |
            var axios = require('axios');

            var config = {
              method: 'get',
            maxBodyLength: Infinity,
              url: 'https://barikoi.xyz/v1/api/search/ward/zone/API_KEY/90.357238/23.806672',
              headers: { }
            };

            axios(config)
            .then(function (response) {
              console.log(JSON.stringify(response.data));
            })
            .catch(function (error) {
              console.log(error);
            });
      responses:
        '200':
          $ref: '#/components/responses/wardzone_success'
        '400':
          $ref: '#/components/responses/missing_parameter'
        '401':
          $ref: '#/components/responses/no_registered_key'
        '402':
          $ref: '#/components/responses/payment_exception'
        '429':
          $ref: '#/components/responses/api_limit_exceeded'
  /v1/api/search/dncc/{api_key}/{longitude}/{latitude}:
    get:
      operationId: dncc_v1
      tags:
        - v1.0
      summary: City Corporation by Geolocation
      parameters:
        - $ref: '#/components/parameters/api_key_path'
        - $ref: '#/components/parameters/longitudePath'
        - $ref: '#/components/parameters/latitudePath'
      x-code-samples:
        - lang: Curl;
          source: >
            curl --location
            'https://barikoi.xyz/v1/api/search/dncc/API_KEY/90.357238/23.806672'
        - lang: Python
          source: >
            import requests

            url =
            "https://barikoi.xyz/v1/api/search/dncc/API_KEY/90.357238/23.806672"

            payload={}

            headers = {}

            response = requests.request("GET", url, headers=headers,
            data=payload)

            print(response.text)
        - lang: Node
          source: |
            var axios = require('axios');

            var config = {
              method: 'get',
            maxBodyLength: Infinity,
              url: 'https://barikoi.xyz/v1/api/search/dncc/API_KEY/90.357238/23.806672',
              headers: { }
            };

            axios(config)
            .then(function (response) {
              console.log(JSON.stringify(response.data));
            })
            .catch(function (error) {
              console.log(error);
            });
      responses:
        '200':
          $ref: '#/components/responses/dncc_success'
        '400':
          $ref: '#/components/responses/missing_parameter'
        '401':
          $ref: '#/components/responses/no_registered_key'
        '402':
          $ref: '#/components/responses/payment_exception'
        '429':
          $ref: '#/components/responses/api_limit_exceeded'
  /v2/api/search/reverse/geocode:
    get:
      operationId: revgeo_v2
      tags:
        - v2.0
      summary: Reverse Geocoding
      description: >-
        This API initially returns id, address, area, city,
        distance_within_meters without any additional call
      parameters:
        - $ref: '#/components/parameters/api_key'
        - $ref: '#/components/parameters/longitude'
        - $ref: '#/components/parameters/latitude'
        - $ref: '#/components/parameters/district'
        - $ref: '#/components/parameters/post_code'
        - $ref: '#/components/parameters/country'
        - $ref: '#/components/parameters/sub_district'
        - $ref: '#/components/parameters/union'
        - $ref: '#/components/parameters/pauroshova'
        - $ref: '#/components/parameters/location_type'
        - $ref: '#/components/parameters/division'
        - $ref: '#/components/parameters/address'
        - $ref: '#/components/parameters/area'
        - $ref: '#/components/parameters/bangla'
      x-code-samples:
        - lang: Curl
          source: >
            curl --location
            'https://barikoi.xyz/v2/api/search/reverse/geocode?api_key=API_KEY&longitude=90.35722628659195&latitude=23.806703092211507&district=true&post_code=true&country=true&sub_district=true&union=true&pauroshova=true&location_type=true&division=true&address=true&area=true&bangla=true'
        - lang: Python
          source: >
            import requests

            url =
            "https://barikoi.xyz/v2/api/search/reverse/geocode?api_key=API_KEY&longitude=90.35722628659195&latitude=23.806703092211507&district=true&post_code=true&country=true&sub_district=true&union=true&pauroshova=true&location_type=true&division=true&address=true&area=true&bangla=true"

            payload={}

            headers = {}

            response = requests.request("GET", url, headers=headers,
            data=payload)

            print(response.text)
        - lang: Node
          source: |
            var axios = require('axios');
            var config = {
              method: 'get',
              maxBodyLength: Infinity,
              url: 'https://barikoi.xyz/v2/api/search/reverse/geocode?api_key=API_KEY&longitude=90.35722628659195&latitude=23.806703092211507&district=true&post_code=true&country=true&sub_district=true&union=true&pauroshova=true&location_type=true&division=true&address=true&area=true&bangla=true',
              headers: { }
            };
            axios(config)
            .then(function (response) {
              console.log(JSON.stringify(response.data));
            })
            .catch(function (error) {
              console.log(error);
            });
      responses:
        '200':
          $ref: '#/components/responses/rev_geo_success'
        '400':
          $ref: '#/components/responses/missing_parameter'
        '401':
          $ref: '#/components/responses/no_registered_key'
        '402':
          $ref: '#/components/responses/payment_exception'
        '429':
          $ref: '#/components/responses/api_limit_exceeded'
  /v2/api/search/autocomplete/place:
    get:
      operationId: autocomplete_v2
      tags:
        - v2.0
      summary: Autocomplete
      description: >-
        Barikoi Autocomplete return's a place's id, longitude, latitude,
        address, city, area, postCode, pType & uCode
      parameters:
        - $ref: '#/components/parameters/api_key'
        - $ref: '#/components/parameters/q'
        - $ref: '#/components/parameters/city'
        - $ref: '#/components/parameters/bangla'
      x-code-samples:
        - lang: Curl
          source: >
            curl --location
            'https://barikoi.xyz/v2/api/search/autocomplete/place?api_key=API_KEY&q=jessore&city=dhaka&bangla=true'
        - lang: Python
          source: >
            import requests

            url =
            "https://barikoi.xyz/v2/api/search/autocomplete/place?api_key=API_KEY&q=jessore&city=dhaka&bangla=true"

            payload={}

            headers = {}

            response = requests.request("GET", url, headers=headers,
            data=payload)

            print(response.text)
        - lang: node
          source: |
            var axios = require('axios');
            var config = {
              method: 'get',
              maxBodyLength: Infinity,
              url: 'https://barikoi.xyz/v2/api/search/autocomplete/place?api_key=API_KEY&q=jessore&city=dhaka&bangla=true',
              headers: { }
            };
            axios(config)
            .then(function (response) {
              console.log(JSON.stringify(response.data));
            })
            .catch(function (error) {
              console.log(error);
            });
      responses:
        '200':
          $ref: '#/components/responses/autocomplete_bangla_success'
        '400':
          $ref: '#/components/responses/missing_parameter'
        '401':
          $ref: '#/components/responses/no_registered_key'
        '402':
          $ref: '#/components/responses/payment_exception'
        '429':
          $ref: '#/components/responses/api_limit_exceeded'
  /v2/api/search/rupantor/geocode?:
    post:
      operationId: rupantor_geocoder_v2
      tags:
        - v2.0
      summary: Rupantor Geocoder
      description: >-
        Rupantor Geocoder API for Developers. It formats the given address and
        searches for the address and gives a status if the address is complete
        or not. Rupantor Geocoder only supports FormData. So use FormData object
        to send your data. Rupantor Geocoder needs Geocode API to function
        properly. One Rupantor Geocoder request requires two Geocode API
        requests.
      parameters:
        - $ref: '#/components/parameters/api_key'
      x-code-samples:
        - lang: Curl
          source: >
            curl --location
            'https://barikoi.xyz/v2/api/search/rupantor/geocode?api_key=API_KEY'
            \

            --form 'q="shawrapara"' \

            --form 'thana="yes"' \

            --form 'district="yes"' \

            --form 'bangla="yes"'
        - lang: Python
          source: >
            import requests

            url =
            "https://barikoi.xyz/v2/api/search/rupantor/geocode?api_key=API_KEY"

            payload={'q': 'shawrapara',

            'thana': 'yes',

            'district': 'yes',

            'bangla': 'yes'}

            files=[]

            headers = {}

            response = requests.request("POST", url, headers=headers,
            data=payload, files=files)

            print(response.text)
        - lang: Node
          source: |
            var axios = require('axios');
            var FormData = require('form-data');
            var data = new FormData();
            data.append('q', 'shawrapara');
            data.append('thana', 'yes');
            data.append('district', 'yes');
            data.append('bangla', 'yes');
            var config = {
              method: 'post',
              maxBodyLength: Infinity,
              url: 'https://barikoi.xyz/v2/api/search/rupantor/geocode?api_key=API_KEY',
              headers: { 
                ...data.getHeaders()
              },
              data : data
            };
            axios(config)
            .then(function (response) {
              console.log(JSON.stringify(response.data));
            })
            .catch(function (error) {
              console.log(error);
            });
      requestBody:
        required: true
        content:
          application/x-www-form-urlencoded:
            schema:
              $ref: '#/components/schemas/rupantor_geocoder_form_v2'
      responses:
        '200':
          $ref: '#/components/responses/rupantor_geocoder_success'
        '400':
          $ref: '#/components/responses/missing_parameter'
        '401':
          $ref: '#/components/responses/no_registered_key'
        '402':
          $ref: '#/components/responses/payment_exception'
        '429':
          $ref: '#/components/responses/api_limit_exceeded'
  /v2/api/search/rupantor/geocode:
    post:
      operationId: rupantor_address_match_v2
      tags:
        - v2.0
      summary: Rupantor Address Match
      description: >-
        Rupantor Address Matcher API matches two different given address and
        returns match percentage and match status.
      parameters:
        - $ref: '#/components/parameters/api_key'
      x-code-samples:
        - lang: Curl
          source: >
            curl --location
            'https://barikoi.xyz/v2/api/search/rupantor/geocode?api_key=API_KEY'
            \

            --form 'q="হাউস ১৮, রোড ৫, ব্লক জি, সেকশন ২ মিরপুর"' \

            --form 'q2="house 18, road 5, block j, section 2, mirpur"' \

            --form 'match="yes"'
        - lang: Python
          source: >
            import requests

            url =
            "https://barikoi.xyz/v2/api/search/rupantor/geocode?api_key=API_KEY"            

            payload={'q': 'হাউস ১৮, রোড ৫, ব্লক জি, সেকশন ২ মিরপুর',

            'q2': 'house 18, road 5, block j, section 2, mirpur',

            'match': 'yes'}

            files=[            

            ]

            headers = {}            

            response = requests.request("POST", url, headers=headers,
            data=payload, files=files)            

            print(response.text)
        - lang: Node
          source: |
            var axios = require('axios');
            var FormData = require('form-data');
            var data = new FormData();
            data.append('q', 'হাউস ১৮, রোড ৫, ব্লক জি, সেকশন ২ মিরপুর');
            data.append('q2', 'house 18, road 5, block j, section 2, mirpur');
            data.append('match', 'yes');

            var config = {
              method: 'post',
            maxBodyLength: Infinity,
              url: 'https://barikoi.xyz/v2/api/search/rupantor/geocode?api_key=API_KEY',
              headers: { 
                ...data.getHeaders()
              },
              data : data
            };

            axios(config)
            .then(function (response) {
              console.log(JSON.stringify(response.data));
            })
            .catch(function (error) {
              console.log(error);
            });
      requestBody:
        required: true
        content:
          application/x-www-form-urlencoded:
            schema:
              $ref: '#/components/schemas/rupantor_address_match_form'
      responses:
        '200':
          $ref: '#/components/responses/rupantor_address_match_success'
        '400':
          $ref: '#/components/responses/missing_parameter'
        '401':
          $ref: '#/components/responses/no_registered_key'
        '402':
          $ref: '#/components/responses/payment_exception'
        '429':
          $ref: '#/components/responses/api_limit_exceeded'
  /v2/api/route/{coordinates}:
    get:
      operationId: route
      tags:
        - v2.0
      summary: Route
      description: ' '
      parameters:
        - $ref: '#/components/parameters/api_key'
        - $ref: '#/components/parameters/coordinates'
      x-code-samples:
        - lang: Curl
          source: >
            curl --location
            'https://barikoi.xyz/v2/api/route/90.362548828125,23.94107556246209;90.31585693359375,24.134221690669204?api_key=API_KEY'
        - lang: Python
          source: >
            import requests

            url =
            "https://barikoi.xyz/v2/api/route/90.362548828125,23.94107556246209;90.31585693359375,24.134221690669204?api_key=API_KEY"

            payload={}

            headers = {}

            response = requests.request("GET", url, headers=headers,
            data=payload)

            print(response.text)
        - lang: Node
          source: |
            var axios = require('axios');
            var config = {
              method: 'get',
              maxBodyLength: Infinity,
              url: 'https://barikoi.xyz/v2/api/route/90.362548828125,23.94107556246209;90.31585693359375,24.134221690669204?api_key=API_KEY',
              headers: { }
            };
            axios(config)
            .then(function (response) {
              console.log(JSON.stringify(response.data));
            })
            .catch(function (error) {
              console.log(error);
            });
      responses:
        '200':
          $ref: '#/components/responses/routing_success'
        '400':
          $ref: '#/components/responses/missing_parameter'
        '401':
          $ref: '#/components/responses/no_registered_key'
        '402':
          $ref: '#/components/responses/payment_exception'
        '429':
          $ref: '#/components/responses/api_limit_exceeded'
  /v2/api/route/optimized:
    post:
      operationId: route_optimization
      tags:
        - v2.0
      summary: Route Optimization
      description: >+
        This api provides routing details from source to destination points.
        Additional waypoints can also be included in order to get more precise
        routing experience. Maximum 50 waypoints can be included as additional
        points. Content-Types:application/json should be attached to the request
        header in order to match the correct request format.


        Note: Waypoints will be sorted based on given id in ascending order.

      requestBody:
        required: true
        content:
          application/json:
            schema:
              $ref: '#/components/schemas/route_optimization_body'
      x-code-samples:
        - lang: Curl
          source: |
            curl --location 'https://barikoi.xyz/v2/api/route/optimized' \
            --data '{
                "api_key": "API_KEY",
                "source": "23.746086,90.37368",
                "destination": "23.746214,90.371654",
                "profile": "car",
                "geo_points": [
                    {
                        "id": 1,
                        "point": "23.746086,90.37368"
                    },
                    {
                        "id": 2,
                        "point": "23.74577,90.373389"
                    },
                    {
                        "id": 3,
                        "point": "23.74442,90.372909"
                    },
                    {
                        "id": 4,
                        "point": "23.743961,90.37214"
                    }
                ]
            }'
        - lang: Python
          source: >
            import requests

            url = "https://barikoi.xyz/v2/api/route/optimized"

            payload = "{\n    \"api_key\": \"API_KEY\",\n    \"source\":
            \"23.746086,90.37368\",\n    \"destination\":
            \"23.746214,90.371654\",\n    \"profile\": \"car\",\n   
            \"geo_points\": [\n        {\n            \"id\": 1,\n           
            \"point\": \"23.746086,90.37368\"\n        },\n       
            {\n            \"id\": 2,\n            \"point\":
            \"23.74577,90.373389\"\n        },\n        {\n            \"id\":
            3,\n            \"point\": \"23.74442,90.372909\"\n       
            },\n        {\n            \"id\": 4,\n            \"point\":
            \"23.743961,90.37214\"\n        }\n    ]\n}"

            headers = {}

            response = requests.request("POST", url, headers=headers,
            data=payload)

            print(response.text)
        - lang: Node
          source: >
            var axios = require('axios');

            var data = '{\n    "api_key": "API_KEY",\n    "source":
            "23.746086,90.37368",\n    "destination":
            "23.746214,90.371654",\n    "profile": "car",\n    "geo_points":
            [\n        {\n            "id": 1,\n            "point":
            "23.746086,90.37368"\n        },\n        {\n            "id":
            2,\n            "point": "23.74577,90.373389"\n        },\n       
            {\n            "id": 3,\n            "point":
            "23.74442,90.372909"\n        },\n        {\n            "id":
            4,\n            "point": "23.743961,90.37214"\n        }\n    ]\n}';

            var config = {
              method: 'post',
            maxBodyLength: Infinity,
              url: 'https://barikoi.xyz/v2/api/route/optimized',
              headers: { },
              data : data
            };

            axios(config)

            .then(function (response) {
              console.log(JSON.stringify(response.data));
            })

            .catch(function (error) {
              console.log(error);
            });
      responses:
        '200':
          $ref: '#/components/responses/route_optimization_success'
        '400':
          $ref: '#/components/responses/missing_parameter'
        '401':
          $ref: '#/components/responses/no_registered_key'
        '402':
          $ref: '#/components/responses/payment_exception'
        '429':
          $ref: '#/components/responses/api_limit_exceeded'
  /v2/api/route/sorted:
    post:
      operationId: route_location_optimized
      tags:
        - v2.0
      summary: Route Location Optimized
      description: >-
        Location sorting api takes a set of locations with additional payload
        attached with each location considering the first one as the source and
        the last one as the destination. It returns with the sorted location set
        that was provided considering the distance between the locations in
        Kilometers from source to destination. Maximum 50 locations can be
        attached in a row. Content-Types:application/json should be attached to
        the request header in order to match the correct request format.
      requestBody:
        required: true
        content:
          application/json:
            schema:
              $ref: '#/components/schemas/route_location_optimized_body'
      x-code-samples:
        - lang: Curl
          source: |
            curl --location 'https://barikoi.xyz/v2/api/route/sorted' \
            --data '{
                "api_key" : "API_KEY",
                "locations": [
                    {"point": {"lat": 24.439648,"lon" : 90.731277}, "additional_payload" : [{"address" : "Kishoreganj Thana"}]},
                    {"point": {"lat": 23.74608583,"lon" : 90.37368}, "additional_payload" : [{"address" : "House 36, Road 9/A"}]},
                    {"point": {"lat": 24.440899,"lon" : 90.771103}, "additional_payload" : [{"address" : "Monju Villa, House 1244, Hossainpur Road, Nogua"}]},
                    {"point": {"lat": 23.74577034,"lon" : 90.37338898}, "additional_payload" : [{"address" : "House 38, Road 9/A"}]},
                    {"point": {"lat": 23.74441997,"lon" : 90.37290861}, "additional_payload" : [{"address" : "Dhanmondi, Road 8/a"}]}
                ]
            }'
        - lang: Python
          source: >
            import requests

            url = "https://barikoi.xyz/v2/api/route/sorted"

            payload = "{\n    \"api_key\" : \"API_KEY\",\n    \"locations\":
            [\n        {\"point\": {\"lat\": 24.439648,\"lon\" : 90.731277},
            \"additional_payload\" : [{\"address\" : \"Kishoreganj
            Thana\"}]},\n        {\"point\": {\"lat\": 23.74608583,\"lon\" :
            90.37368}, \"additional_payload\" : [{\"address\" : \"House 36, Road
            9/A\"}]},\n        {\"point\": {\"lat\": 24.440899,\"lon\" :
            90.771103}, \"additional_payload\" : [{\"address\" : \"Monju Villa,
            House 1244, Hossainpur Road, Nogua\"}]},\n        {\"point\":
            {\"lat\": 23.74577034,\"lon\" : 90.37338898}, \"additional_payload\"
            : [{\"address\" : \"House 38, Road 9/A\"}]},\n        {\"point\":
            {\"lat\": 23.74441997,\"lon\" : 90.37290861}, \"additional_payload\"
            : [{\"address\" : \"Dhanmondi, Road 8/a\"}]}\n    ]\n}"

            headers = {}

            response = requests.request("POST", url, headers=headers,
            data=payload)

            print(response.text)
        - lang: Node
          source: >
            var axios = require('axios');

            var data = '{\n    "api_key" : "API_KEY",\n    "locations":
            [\n        {"point": {"lat": 24.439648,"lon" : 90.731277},
            "additional_payload" : [{"address" : "Kishoreganj
            Thana"}]},\n        {"point": {"lat": 23.74608583,"lon" : 90.37368},
            "additional_payload" : [{"address" : "House 36, Road
            9/A"}]},\n        {"point": {"lat": 24.440899,"lon" : 90.771103},
            "additional_payload" : [{"address" : "Monju Villa, House 1244,
            Hossainpur Road, Nogua"}]},\n        {"point": {"lat":
            23.74577034,"lon" : 90.37338898}, "additional_payload" : [{"address"
            : "House 38, Road 9/A"}]},\n        {"point": {"lat":
            23.74441997,"lon" : 90.37290861}, "additional_payload" : [{"address"
            : "Dhanmondi, Road 8/a"}]}\n    ]\n}';

            var config = {
              method: 'post',
            maxBodyLength: Infinity,
              url: 'https://barikoi.xyz/v2/api/route/sorted',
              headers: { },
              data : data
            };

            axios(config)

            .then(function (response) {
              console.log(JSON.stringify(response.data));
            })

            .catch(function (error) {
              console.log(error);
            });
      responses:
        '200':
          $ref: '#/components/responses/route_location_optimized_success'
        '400':
          $ref: '#/components/responses/missing_parameter'
        '401':
          $ref: '#/components/responses/no_registered_key'
        '402':
          $ref: '#/components/responses/payment_exception'
        '429':
          $ref: '#/components/responses/api_limit_exceeded'
  /v2/api/routing/nearest:
    get:
      operationId: snap_to_road_v2
      tags:
        - v2.0
      summary: Snap to Road
      description: ' '
      parameters:
        - $ref: '#/components/parameters/api_key'
        - $ref: '#/components/parameters/point'
      x-code-samples:
        - lang: Curl
          source: >
            curl --location
            'https://barikoi.xyz/v2/api/routing/nearest?point=23.806525320635505,90.36129978225671&api_key=API_KEY'
        - lang: Python
          source: >
            import requests

            url =
            "https://barikoi.xyz/v2/api/routing/nearest?point=23.806525320635505,90.36129978225671&api_key=API_KEY"

            payload={}

            headers = {}

            response = requests.request("GET", url, headers=headers,
            data=payload)

            print(response.text)
        - lang: Node
          source: |
            var axios = require('axios');

            var config = {
              method: 'get',
            maxBodyLength: Infinity,
              url: 'https://barikoi.xyz/v2/api/routing/nearest?point=23.806525320635505,90.36129978225671&api_key=API_KEY',
              headers: { }
            };

            axios(config)
            .then(function (response) {
              console.log(JSON.stringify(response.data));
            })
            .catch(function (error) {
              console.log(error);
            });
      responses:
        '200':
          $ref: '#/components/responses/span_to_road_success'
        '400':
          $ref: '#/components/responses/missing_parameter'
        '401':
          $ref: '#/components/responses/no_registered_key'
        '402':
          $ref: '#/components/responses/payment_exception'
        '429':
          $ref: '#/components/responses/api_limit_exceeded'
  /v2/api/routing/matching:
    get:
      operationId: route_match_v2
      tags:
        - v2.0
      summary: Route Match
      parameters:
        - $ref: '#/components/parameters/api_key'
        - $ref: '#/components/parameters/points'
      x-code-samples:
        - lang: Curl
          source: >
            curl --location --request GET
            'https://barikoi.xyz/v2/api/routing/matching?points=90.38436119310136,23.7267599142696;90.38438265469962,23.726622279057658&api_key=<BARIKOI_API_KEY>'
        - lang: Python
          source: >
            import requests

            url =
            "https://barikoi.xyz/v2/api/routing/matching?points=90.38436119310136,23.7267599142696;90.38438265469962,23.726622279057658&api_key=API_KEY"

            payload={}

            headers = {}

            response = requests.request("GET", url, headers=headers,
            data=payload)            

            print(response.text)
        - lang: Node
          source: |
            var axios = require('axios');

            var config = {
              method: 'get',
            maxBodyLength: Infinity,
              url: 'https://barikoi.xyz/v2/api/routing/matching?points=90.38436119310136,23.7267599142696;90.38438265469962,23.726622279057658&api_key=API_KEY',
              headers: { }
            };

            axios(config)
            .then(function (response) {
              console.log(JSON.stringify(response.data));
            })
            .catch(function (error) {
              console.log(error);
            });
      responses:
        '200':
          $ref: '#/components/responses/route_match_success'
        '400':
          $ref: '#/components/responses/missing_parameter'
        '401':
          $ref: '#/components/responses/no_registered_key'
        '402':
          $ref: '#/components/responses/payment_exception'
        '429':
          $ref: '#/components/responses/api_limit_exceeded'
  /v2/api/search/area:
    get:
      operationId: area_v2
      tags:
        - v2.0
      summary: Area
      parameters:
        - $ref: '#/components/parameters/api_key'
        - $ref: '#/components/parameters/longitude'
        - $ref: '#/components/parameters/latitude'
      x-code-samples:
        - lang: Curl
          source: >
            curl --location
            'https://barikoi.xyz/v2/api/search/area?api_key=API_KEY&latitude=23.863233589986915&longitude=90.41347324848176'
        - lang: Python
          source: >
            import requests

            url =
            "https://barikoi.xyz/v2/api/search/area?api_key=API_KEY&latitude=23.863233589986915&longitude=90.41347324848176"          

            payload={}

            headers = {}          

            response = requests.request("GET", url, headers=headers,
            data=payload)        

            print(response.text)
        - lang: Node
          source: |
            var axios = require('axios');

            var config = {
              method: 'get',
            maxBodyLength: Infinity,
              url: 'https://barikoi.xyz/v2/api/search/area?api_key=API_KEY&latitude=23.863233589986915&longitude=90.41347324848176',
              headers: { }
            };

            axios(config)
            .then(function (response) {
              console.log(JSON.stringify(response.data));
            })
            .catch(function (error) {
              console.log(error);
            });
      responses:
        '200':
          $ref: '#/components/responses/area_success'
        '400':
          $ref: '#/components/responses/missing_parameter'
        '401':
          $ref: '#/components/responses/no_registered_key'
        '402':
          $ref: '#/components/responses/payment_exception'
        '429':
          $ref: '#/components/responses/api_limit_exceeded'
  /v2/api/search/get/ward/geometry:
    get:
      operationId: ward_v2
      tags:
        - v2.0
      summary: Ward Geometry
      parameters:
        - $ref: '#/components/parameters/api_key'
        - $ref: '#/components/parameters/ward'
      x-code-samples:
        - lang: Curl
          source: >
            curl --location
            'https://barikoi.xyz/v2/api/search/get/ward/geometry?api_key=API_KEY&ward_number=31'
        - lang: Python
          source: >
            import requests

            url =
            "https://barikoi.xyz/v2/api/search/get/ward/geometry?api_key=API_KEY&ward_number=31"

            payload={}

            headers = {}

            response = requests.request("GET", url, headers=headers,
            data=payload)

            print(response.text)
        - lang: Node
          source: |
            var axios = require('axios');

            var config = {
              method: 'get',
            maxBodyLength: Infinity,
              url: 'https://barikoi.xyz/v2/api/search/get/ward/geometry?api_key=API_KEY&ward_number=31',
              headers: { }
            };

            axios(config)
            .then(function (response) {
              console.log(JSON.stringify(response.data));
            })
            .catch(function (error) {
              console.log(error);
            });
      responses:
        '200':
          $ref: '#/components/responses/ward_geometry_success'
        '400':
          $ref: '#/components/responses/missing_parameter'
        '401':
          $ref: '#/components/responses/no_registered_key'
        '402':
          $ref: '#/components/responses/payment_exception'
        '429':
          $ref: '#/components/responses/api_limit_exceeded'
  /v2/api/search/nearby/0.5/10:
    get:
      operationId: nearby_query_param
      tags:
        - v2.0
      summary: Nearby
      parameters:
        - $ref: '#/components/parameters/api_key'
        - $ref: '#/components/parameters/longitude'
        - $ref: '#/components/parameters/latitude'
      x-code-samples:
        - lang: Curl
          source: >
            curl --location
            'https://barikoi.xyz/v2/api/search/nearby/0.5/10?api_key=API_KEY&longitude=90.38305163&latitude=23.87188719'
        - lang: Python
          source: >
            import requests

            url =
            "https://barikoi.xyz/v2/api/search/nearby/0.5/10?api_key=API_KEY&longitude=90.38305163&latitude=23.87188719"

            payload={}

            headers = {}

            response = requests.request("GET", url, headers=headers,
            data=payload)

            print(response.text)
        - lang: Node
          source: |
            var axios = require('axios');

            var config = {
              method: 'get',
            maxBodyLength: Infinity,
              url: 'https://barikoi.xyz/v2/api/search/nearby/0.5/10?api_key=API_KEY&longitude=90.38305163&latitude=23.87188719',
              headers: { }
            };

            axios(config)
            .then(function (response) {
              console.log(JSON.stringify(response.data));
            })
            .catch(function (error) {
              console.log(error);
            });
      responses:
        '200':
          $ref: '#/components/responses/nearby_success'
        '400':
          $ref: '#/components/responses/missing_parameter'
        '401':
          $ref: '#/components/responses/no_registered_key'
        '402':
          $ref: '#/components/responses/payment_exception'
        '429':
          $ref: '#/components/responses/api_limit_exceeded'
  /v2/api/point-in-polygon:
    post:
      operationId: point-in-polygon_v2
      tags:
        - v2.0
      summary: Point in Polygon
      parameters:
        - $ref: '#/components/parameters/api_key'
      x-code-samples:
        - lang: Curl
          source: >
            curl --location
            'https://barikoi.xyz/v2/api/point-in-polygon?api_key=API_KEY' \

            --form 'point="90.41697542000593,23.780273491928714"'
        - lang: Python
          source: >
            import requests

            url = "https://barikoi.xyz/v2/api/point-in-polygon?api_key=API_KEY"

            payload={'point': '90.41697542000593,23.780273491928714'}

            files=[

            ]

            headers = {}

            response = requests.request("POST", url, headers=headers,
            data=payload, files=files)

            print(response.text)
        - lang: Node
          source: |
            var axios = require('axios');
            var FormData = require('form-data');
            var data = new FormData();
            data.append('point', '90.41697542000593,23.780273491928714');

            var config = {
              method: 'post',
            maxBodyLength: Infinity,
              url: 'https://barikoi.xyz/v2/api/point-in-polygon?api_key=API_KEY',
              headers: { 
                ...data.getHeaders()
              },
              data : data
            };

            axios(config)
            .then(function (response) {
              console.log(JSON.stringify(response.data));
            })
            .catch(function (error) {
              console.log(error);
            });
      requestBody:
        required: true
        content:
          application/x-www-form-urlencoded:
            schema:
              $ref: '#/components/schemas/point_in_polygon_form'
      responses:
        '200':
          $ref: '#/components/responses/point_in_polygon_success'
        '400':
          $ref: '#/components/responses/missing_parameter'
        '401':
          $ref: '#/components/responses/no_registered_key'
        '402':
          $ref: '#/components/responses/payment_exception'
        '429':
          $ref: '#/components/responses/api_limit_exceeded'
components:
  securitySchemes:
    api_key:
      type: apiKey
      name: api_key
      in: query
  parameters:
    api_keyParam:
      $ref: '#/components/parameters/api_key'
    api_keyPathParam:
      $ref: '#/components/parameters/api_key_path'
    api_keyPathParamUpper:
      $ref: '#/components/parameters/api_key_path_upper'
    longitudeParam:
      $ref: '#/components/parameters/longitude'
    latitudeParam:
      $ref: '#/components/parameters/latitude'
    longitudePathParam:
      $ref: '#/components/parameters/longitudePath'
    latitudePathParam:
      $ref: '#/components/parameters/latitudePath'
    districtParam:
      $ref: '#/components/parameters/district'
    cityParam:
      $ref: '#/components/parameters/city'
    city_PathParam:
      $ref: '#/components/parameters/city_path'
    post_codeParam:
      $ref: '#/components/parameters/post_code'
    post_officeParam:
      $ref: '#/components/parameters/post_office'
    thanaParam:
      $ref: '#/components/parameters/thana'
    countryParam:
      $ref: '#/components/parameters/country'
    sub_districtParam:
      $ref: '#/components/parameters/sub_district'
    unionParam:
      $ref: '#/components/parameters/union'
    pauroshovaParam:
      $ref: '#/components/parameters/pauroshova'
    location_typeParam:
      $ref: '#/components/parameters/location_type'
    divisionParam:
      $ref: '#/components/parameters/division'
    addressParam:
      $ref: '#/components/parameters/address'
    areaParam:
      $ref: '#/components/parameters/area'
    banglaParam:
      $ref: '#/components/parameters/bangla'
    distanceParam:
      $ref: '#/components/parameters/distance'
    limitParam:
      $ref: '#/components/parameters/limit'
    ptypeParam:
      $ref: '#/components/parameters/ptype'
    qParam:
      $ref: '#/components/parameters/q'
    qParamCities:
      $ref: '#/components/parameters/q_cities'
    qParamUnions:
      $ref: '#/components/parameters/q_unions'
    qParamSubdistricts:
      $ref: '#/components/parameters/q_subdistricts'
    qParamDistricts:
      $ref: '#/components/parameters/q_districts'
    q2Param:
      $ref: '#/components/parameters/q2'
    matchParam:
      $ref: '#/components/parameters/match'
    pointParam:
      $ref: '#/components/parameters/point'
    pointsParam:
      $ref: '#/components/parameters/points'
    pointsPathParam:
      $ref: '#/components/parameters/pointsPath'
    geometriesParam:
      $ref: '#/components/parameters/geometries'
    coordinatesParam:
      $ref: '#/components/parameters/coordinates'
    industrialParam:
      $ref: '#/components/parameters/industrial'
    wardParam:
      $ref: '#/components/parameters/ward'
    api_key_path:
      name: api_key
      in: path
      required: true
      schema:
        type: string
        description: API_KEY
    longitude:
      name: longitude
      in: query
      required: true
      schema:
        type: number
        description: '90.35722628659195'
    latitude:
      name: latitude
      in: query
      required: true
      schema:
        type: number
        description: '23.806703092211507'
    district:
      name: district
      in: query
      required: false
      schema:
        type: boolean
        description: 'true'
    post_code:
      name: post_code
      in: query
      required: false
      schema:
        type: boolean
        description: 'true'
    country:
      name: country
      in: query
      required: false
      schema:
        type: boolean
        description: 'true'
    sub_district:
      name: sub_district
      in: query
      required: false
      schema:
        type: boolean
        description: 'true'
    union:
      name: union
      in: query
      required: false
      schema:
        type: boolean
        description: 'true'
    pauroshova:
      name: pauroshova
      in: query
      required: false
      schema:
        type: boolean
        description: 'true'
    location_type:
      name: location_type
      in: query
      required: false
      schema:
        type: boolean
        description: 'true'
    division:
      name: division
      in: query
      required: false
      schema:
        type: boolean
        description: 'true'
    address:
      name: address
      in: query
      required: false
      schema:
        type: boolean
        description: 'true'
    area:
      name: area
      in: query
      required: false
      schema:
        type: boolean
        description: 'true'
    bangla:
      name: bangla
      in: query
      required: false
      schema:
        type: boolean
        description: 'true'
    q:
      name: q
      in: query
      required: true
      schema:
        type: string
        description: q
    city:
      name: city
      in: query
      required: true
      schema:
        type: string
        description: dhaka
    post_office:
      name: post_office
      in: query
      required: false
      schema:
        type: boolean
        description: 'true'
    industrial:
      name: industrial
      in: query
      required: false
      schema:
        type: boolean
        description: 'true'
    longitudePath:
      name: longitude
      in: path
      required: true
      schema:
        type: number
        description: '90.35722628659195'
    latitudePath:
      name: latitude
      in: path
      required: true
      schema:
        type: number
        description: '23.806703092211507'
    api_key_path_upper:
      name: API_KEY
      in: path
      required: true
      schema:
        type: string
        description: API_KEY
    coordinates:
      name: coordinates
      in: path
      required: true
      schema:
        type: string
        description: String of format `{longitude},{latitude};{longitude},{latitude}`.
    point:
      name: point
      in: query
      required: true
      schema:
        type: string
        example: 23.80474653651567,90.36288913339376
    points:
      name: points
      in: query
      required: true
      schema:
        type: string
        example: >-
          90.38436119310136,23.7267599142696;90.38438265469962,23.726622279057658
    q_districts:
      name: q
      in: query
      required: true
      schema:
        type: string
        description: dhaka
    q_subdistricts:
      name: q
      in: query
      required: true
      schema:
        type: string
        description: khilgaon
    q_cities:
      name: q
      in: query
      required: true
      schema:
        type: string
        description: dhaka
    q_unions:
      name: q
      in: query
      required: true
      schema:
        type: string
        description: abaipur
    api_key:
      name: api_key
      in: query
      required: true
      schema:
        type: string
        description: API_KEY
    ward:
      name: ward_number
      in: query
      required: true
      schema:
        type: number
        description: '31'
    city_path:
      name: city_path
      in: path
      required: true
      schema:
        type: boolean
        description: city
    thana:
      name: thana
      in: query
      required: false
      schema:
        type: boolean
        description: 'true'
    distance:
      name: distance
      in: path
      required: true
      schema:
        type: number
        description: distance in meters
    limit:
      name: limit
      in: path
      required: true
      schema:
        type: integer
        description: limit
    ptype:
      name: ptype
      in: query
      required: true
      schema:
        type: string
        description: ptype
    q2:
      name: q2
      in: query
      required: true
      schema:
        type: string
        description: q2
    match:
      name: match
      in: query
      required: true
      schema:
        type: boolean
        description: 'true'
    pointsPath:
      name: points
      in: path
      required: true
      schema:
        type: string
        example: >-
          90.38436119310136,23.7267599142696;90.38438265469962,23.726622279057658
    geometries:
      name: geometries
      in: query
      required: false
      schema:
        type: string
        description: >-
          Returned route geometry format (influences overview and per step).
          Expected values are, `polyline`, `polyline6`, `geojson`
        default: polyline
  schemas:
    api_limit_exceeded: &ref_4
      type: object
      properties:
        message:
          type: string
          default: API LIMIT EXCEEDED
        status:
          type: integer
          default: 429
    no_registered_key: &ref_2
      type: object
      properties:
        message:
          type: string
          default: Invalid or No Registered Key
        status:
          type: integer
          default: 401
    missing_parameter: &ref_1
      type: object
      properties:
        message:
          type: string
          default: Parameter missing
        status:
          type: integer
          default: 400
    payment_exception: &ref_3
      type: object
      properties:
        message:
          type: string
          default: Payment exception
        status:
          type: integer
          default: 402
    rev_geo_success: &ref_0
      type: object
      properties:
        place:
          type: object
          properties:
            id:
              type: integer
              example: 534001
            distance_within_meters:
              type: number
              example: 3.9083
            address:
              type: string
              example: হাউজ ২০, এভিনিউ ৩, লেন ২৫, ব্লক ডি, সেকশন ১১, মিরপুর
            area:
              type: string
              example: মিরপুর
            city:
              type: string
              example: ঢাকা
            postCode:
              type: integer
              example: 1216
            district:
              type: string
              example: ঢাকা
            country:
              type: string
              example: বাংলাদেশ
            sub_district:
              type: string
              example: পল্লবী
            division:
              type: string
              example: ঢাকা
            pauroshova:
              type: string
              example: null
            union:
              type: string
              example: null
            location_type:
              type: string
              example: শহর
            address_components:
              type: object
              properties:
                place_name:
                  type: string
                  example: null
                house:
                  type: string
                  example: null
                road:
                  type: string
                  example: null
            area_components:
              type: object
              properties:
                area:
                  type: string
                  example: মিরপুর
                sub_area:
                  type: string
                  example: Section 11
        status:
          type: integer
          default: 200
    dncc_success: &ref_18
      type: object
      properties:
        message:
          type: string
          default: dncc
        status:
          type: integer
          default: 200
    wardzone_success: &ref_17
      type: object
      properties:
        ward:
          type: integer
          default: 7
        ward area:
          type: string
          default: >-
            {"type": "Polygon", "coordinates": [[[90.366213, 23.815692],
            [90.366953, 23.812939], [90.367616, 23.810559], [90.367781,
            23.809919], [90.367905, 23.809467], [90.368214, 23.808347],
            [90.368475, 23.807438], [90.368488, 23.807388], [90.368568,
            23.807089], [90.368485, 23.807074], [90.367573, 23.806866],
            [90.366942, 23.806706], [90.366865, 23.806684], [90.366787,
            23.806672], [90.366232, 23.80652], [90.365963, 23.806441],
            [90.365687, 23.806311], [90.365108, 23.806016], [90.364421,
            23.805636], [90.363533, 23.805096], [90.362932, 23.804733],
            [90.362015, 23.804151], [90.360848, 23.803413], [90.35955,
            23.802584], [90.358351, 23.801803], [90.357756, 23.801423],
            [90.357077, 23.800988], [90.356745, 23.800775], [90.356026,
            23.800323], [90.355967, 23.800281], [90.355285, 23.799847],
            [90.355065, 23.800176], [90.35476, 23.800618], [90.354457,
            23.801035], [90.353916, 23.801826], [90.353375, 23.802613],
            [90.352968, 23.803212], [90.352523, 23.803857], [90.352153,
            23.804365], [90.351777, 23.804927], [90.351689, 23.80518],
            [90.351641, 23.805388], [90.351569, 23.806026], [90.351112,
            23.807526], [90.354567, 23.809209], [90.353773, 23.809533],
            [90.353622, 23.810132], [90.354148, 23.810377], [90.354159,
            23.810603], [90.354041, 23.81079], [90.353655, 23.810897],
            [90.353408, 23.810867], [90.352924, 23.813075], [90.35491,
            23.813793], [90.35475, 23.814563], [90.354568, 23.814971],
            [90.356037, 23.815354], [90.357506, 23.815736], [90.357828,
            23.815167], [90.358622, 23.815088], [90.358686, 23.813581],
            [90.35933, 23.812713], [90.361196, 23.812654], [90.362447,
            23.814799], [90.363237, 23.815187], [90.366213, 23.815692]]]}
        zone:
          type: integer
          default: 2
    ward_success: &ref_15
      type: array
      items:
        type: object
        properties:
          Ward:
            type: integer
            default: 7
    ward_geometry_success: &ref_23
      type: object
      properties:
        ward:
          type: object
          properties:
            ward_number:
              type: number
              default: 31
            geometry:
              type: string
              default: >-
                {"type": "Polygon", "coordinates": [[[90.366198, 23.762884],
                [90.366385, 23.762196], [90.364897, 23.761787], [90.365314,
                23.76058], [90.365408, 23.760335], [90.365535, 23.759973],
                [90.365757, 23.759365], [90.366425, 23.759635], [90.367205,
                23.757316], [90.367301, 23.757033], [90.366696, 23.756858],
                [90.366887, 23.755973], [90.366429, 23.755908], [90.366556,
                23.755447], [90.36579, 23.75532], [90.36592, 23.754774],
                [90.36532, 23.754647], [90.364874, 23.754292], [90.363961,
                23.755053], [90.363957, 23.75505], [90.363949, 23.755056],
                [90.363947, 23.75506], [90.363674, 23.755298], [90.363619,
                23.755345], [90.36357, 23.755387], [90.363358, 23.755567],
                [90.362842, 23.755997], [90.362214, 23.756507], [90.361939,
                23.756734], [90.361737, 23.756911], [90.361514, 23.757009],
                [90.361299, 23.757099], [90.361199, 23.75713], [90.3611,
                23.757163], [90.360846, 23.75726], [90.360334, 23.757679],
                [90.360285, 23.75774], [90.359613, 23.758563], [90.359547,
                23.758677], [90.35929, 23.759151], [90.359081, 23.759592],
                [90.358951, 23.76], [90.358912, 23.760536], [90.358963,
                23.760893], [90.358951, 23.76096], [90.358921, 23.761251],
                [90.35892, 23.761312], [90.358897, 23.761692], [90.358876,
                23.761962], [90.35885, 23.76219], [90.35885, 23.762254],
                [90.358819, 23.762396], [90.358897, 23.762418], [90.359483,
                23.762571], [90.360431, 23.762849], [90.360823, 23.762947],
                [90.361373, 23.763125], [90.361702, 23.763216], [90.361932,
                23.763266], [90.362112, 23.763334], [90.362374, 23.763419],
                [90.362698, 23.7635], [90.362898, 23.763573], [90.363113,
                23.763628], [90.363989, 23.763872], [90.364428, 23.763995],
                [90.365048, 23.764177], [90.365204, 23.764218], [90.365492,
                23.764295], [90.365577, 23.764068], [90.365709, 23.763695],
                [90.365841, 23.763328], [90.365897, 23.763149], [90.365932,
                23.763059], [90.366009, 23.762979], [90.366044, 23.762941],
                [90.366152, 23.762898], [90.366198, 23.762884]]]}
        status:
          type: number
          default: 200
    unions_success: &ref_14
      type: object
      properties:
        places:
          type: array
          items:
            type: object
            properties:
              id:
                type: number
                default: 1
              name:
                type: string
                default: Abaipur
              sub_district:
                type: string
                default: Shailkupa
              center:
                type: string
                default: >-
                  {"type": "Point", "coordinates": [89.32057699103409,
                  23.59762103167178]}
        status:
          type: number
          default: 200
    cities_success: &ref_13
      type: object
      properties:
        places:
          type: array
          items:
            - type: object
              properties:
                name:
                  type: string
                  default: Dhaka
                areas:
                  type: array
                  items:
                    - type: object
                      properties:
                        name:
                          type: string
                          default: Moghbazar
                    - type: object
                      properties:
                        name:
                          type: string
                          default: Dhaka Cantonment
                    - type: object
                      properties:
                        name:
                          type: string
                          default: Gendaria
                    - type: object
                      properties:
                        name:
                          type: string
                          default: Sher E Bangla Nagar
                    - type: object
                      properties:
                        name:
                          type: string
                          default: Tejgaon
                    - type: object
                      properties:
                        name:
                          type: string
                          default: Banasree
                    - type: object
                      properties:
                        name:
                          type: string
                          default: Dakkhinkhan
                    - type: object
                      properties:
                        name:
                          type: string
                          default: Mohakhali
            - type: object
              properties:
                name:
                  type: string
                  default: Joldhaka
                areas:
                  type: array
                  items:
                    - type: object
        status:
          type: number
          default: 200
    zone_success: &ref_16
      type: array
      items:
        type: object
        properties:
          Zone:
            type: integer
            default: 2
    subdistricts_success: &ref_12
      type: object
      properties:
        places:
          type: array
          items:
            type: object
            properties:
              id:
                type: number
                default: 280
              name:
                type: string
                default: Khilgaon
              district:
                type: string
                default: Dhaka
              center:
                type: string
                default: >-
                  {"type": "Point", "coordinates": [90.45477443959228,
                  23.759899924349806]}
        status:
          type: number
          default: 200
    districts_success: &ref_11
      type: object
      properties:
        places:
          type: array
          items:
            - type: object
              properties:
                name:
                  type: string
                  default: Dhaka
                areas:
                  type: array
                  items:
                    - type: object
                      properties:
                        name:
                          type: string
                          default: Moghbazar
                    - type: object
                      properties:
                        name:
                          type: string
                          default: Dhaka Cantonment
                    - type: object
                      properties:
                        name:
                          type: string
                          default: Gendaria
                    - type: object
                      properties:
                        name:
                          type: string
                          default: Sher E Bangla Nagar
                    - type: object
                      properties:
                        name:
                          type: string
                          default: Tejgaon
                    - type: object
                      properties:
                        name:
                          type: string
                          default: Banasree
                    - type: object
                      properties:
                        name:
                          type: string
                          default: Dakkhinkhan
                    - type: object
                      properties:
                        name:
                          type: string
                          default: Mohakhali
            - type: object
              properties:
                name:
                  type: string
                  default: Joldhaka
                areas:
                  type: array
                  items:
                    - type: object
        status:
          type: number
          default: 200
    nearby_success: &ref_24
      type: object
      properties:
        places:
          type: array
          items:
            type: object
            properties:
              id:
                type: integer
                example: 4
              name:
                type: string
                example: Uttara sector 12 Park
              distance_in_meters:
                type: number
                example: 0.00045241879869987946
              longitude:
                type: number
                example: 90.383051633835
              latitude:
                type: number
                example: 23.871887192063
              pType:
                type: string
                example: Recreation
              Address:
                type: string
                example: Road 11, Sector 12
              area:
                type: string
                example: Uttara
              city:
                type: string
                example: Dhaka
              postCode:
                type: string
                example: 1230
              subType:
                type: string
                example: PARK
              uCode:
                type: string
                example: OYFR1074
              ST_AsText(location):
                type: string
                example: POINT(90.383051633835 23.871887192063)
        status:
          type: integer
          default: 200
    autocomplete_success: &ref_5
      type: object
      properties:
        places:
          type: array
          items:
            type: object
            properties:
              id:
                type: integer
                example: 882513
              longitude:
                type: number
                example: 90.39752920000001
              latitude:
                type: number
                example: 23.726055300000002
              address:
                type: string
                example: Dhaka Medical College Hospital
              city:
                type: string
                example: Dhaka
              area:
                type: string
                example: Dhaka University Campus
              postCode:
                type: integer
                example: 1000
              pType:
                type: string
                example: Healthcare
              uCode:
                type: string
                example: BXXK5816
        status:
          type: integer
          default: 200
    autocomplete_bangla_success: &ref_19
      type: object
      properties:
        places:
          type: array
          items:
            type: object
            properties:
              id:
                type: integer
                example: 635085
              longitude:
                type: number
                example: 90.369999116958
              latitude:
                type: number
                example: 23.83729875602
              address:
                type: string
                example: Mirpur DOHS, Mirpur DOHS
              address_bn:
                type: string
                example: মিরপুর ডিওএইচএস, মিরপুর ডিওএইচএস, মিরপুর, ঢাকা
              city:
                type: string
                example: Dhaka
              city_bn:
                type: string
                example: ঢাকা
              area:
                type: string
                example: Dhaka University Campus
              area_bn:
                type: string
                example: মিরপুর
              postCode:
                type: integer
                example: 1216
              pType:
                type: string
                example: Admin
              uCode:
                type: string
                example: PFSU6037
        status:
          type: integer
          default: 200
    rupantor_geocoder_form_v1:
      type: object
      properties:
        q:
          type: string
          description: matikata rd basa 572/k barikoi
        thana:
          type: boolean
          description: 'yes'
        district:
          type: boolean
          description: 'yes'
        bangla:
          type: boolean
          description: 'yes'
      required:
        - q
    rupantor_geocoder_form_v2:
      type: object
      properties:
        q:
          type: string
          description: shawrapara
        thana:
          type: boolean
          description: 'yes'
        district:
          type: boolean
          description: 'yes'
        bangla:
          type: boolean
          description: 'yes'
      required:
        - q
    rupantor_geocoder_success: &ref_6
      type: object
      properties:
        given_address:
          type: string
          example: shawrapara
        fixed_address:
          type: string
          example: shewrapara
        bangla_address:
          type: string
          example: শেওড়াপাড়া কবরস্থান, ইস্ট শেওড়াপাড়া, শেওড়াপাড়া, মিরপুর, ঢাকা
        address_status:
          type: string
          example: incomplete
        geocoded_address:
          type: object
          properties:
            Address:
              type: string
              example: >-
                Shewrapara Koborsthan, East Shewrapara, Shewrapara, Mirpur,
                Dhaka
            address_bn:
              type: string
              example: >-
                শেওড়াপাড়া কবরস্থান, ইস্ট শেওড়াপাড়া, শেওড়াপাড়া, মিরপুর,
                ঢাকা
            address_short:
              type: string
              example: Shewrapara Koborsthan, East Shewrapara, Shewrapara
            area:
              type: string
              example: Mirpur
            city:
              type: string
              example: Dhaka
            district:
              type: string
              example: Dhaka
            holding_number:
              type: string
              example: null
            latitude:
              type: number
              example: 23.79175613
            longitude:
              type: number
              example: 90.37567053
            pType:
              type: string
              example: Religious Place
            postCode:
              type: integer
              example: 1216
            road_name_number:
              type: string
              example: null
            sub_area:
              type: string
              example: Shewrapara
            thana:
              type: string
              example: Kafrul
            uCode:
              type: string
              example: TOLJ0109
            unions:
              type: string
              example: null
        confidence_score_percentage:
          type: integer
          example: 55
        status:
          type: integer
          default: 200
    rupantor_address_match_form:
      type: object
      properties:
        q:
          type: string
          description: হাউস ১৮, রোড ৫, ব্লক জি, সেকশন ২ মিরপুর
        q2:
          type: string
          description: house 18, road 5, block G, section 2, mirpur
        match:
          type: boolean
          description: 'yes'
      required:
        - q
        - q2
        - match
    rupantor_address_match_success: &ref_7
      type: object
      properties:
        match:
          type: object
          properties:
            address 1:
              type: string
              example: হাউস ১৮, রোড ৫, ব্লক জি, সেকশন ২ মিরপুর
            address 2:
              type: string
              example: house 18, road 5, block j, section 2, mirpur
            address_short:
              type: string
              example: Shewrapara Koborsthan, East Shewrapara, Shewrapara
            match percentage:
              type: string
              example: 100%
            match status:
              type: string
              example: exact
        status:
          type: integer
          default: 200
    routing_success: &ref_8
      type: object
      properties:
        code:
          type: string
          example: OK
        routes:
          type: array
          items:
            properties:
              geometry:
                type: string
                description: >-
                  The unsimplified geometry of the route segment, depending on
                  the geometries parameter.
                example: >-
                  bqCmhpfPdMaDqEqO`U}MiFc`BueAjZonBlGisJs_@uh@gManAeJaaBzGsZbQ}v@jsAw`@jwAqt@p`BiBtjAvZzhAga@fAmXbQoi@mmA{vA~Ly`CfE
              legs:
                type: array
                items:
                  type: object
                  properties:
                    steps:
                      type: array
                    distance:
                      type: number
                      description: >-
                        The distance traveled by this route leg, in float
                        meters.
                      example: 31580.5
                    duration:
                      type: number
                      description: The estimated travel time, in float number of seconds.
                      example: 5011.5
                    summary:
                      type: string
                      description: Summary of the route taken as string.
                    weight:
                      type: number
                      example: 5011.5
              distance:
                type: number
                description: >-
                  The distance of travel from the maneuver to the subsequent
                  step, in float meters.
                example: 31580.5
              duration:
                type: number
                description: The estimated travel time, in float number of seconds.
                example: 5011.5
              weight_name:
                type: string
                example: routability
              weight:
                type: number
                example: 5011.5
        waypoints:
          type: array
          items:
            - type: object
              properties:
                hint:
                  type: string
                  example: >-
                    1M4MgNbODIAAAAAAUQAAAAAAAABWAgAAAAAAAFZN10EAAAAA6SFHQwAAAABRAAAAAAAAAFYCAADlAAAA6tliBeZObQG10mIF1E9tAQAATwsayG8z
                distance:
                  type: number
                  description: >-
                    The distance of travel from the maneuver to the subsequent
                    step, in float meters.
                  example: 189.684241
                name:
                  type: string
                  example: null
                location:
                  type: array
                  items:
                    - type: number
                      example: 90.364394
                    - type: number
                      example: 23.940838
            - type: object
              properties:
                hint:
                  type: string
                  example: >-
                    iL0PgJa9D4CGAAAAVwAAAH8hAABcDAAAjQGVQqNFPkI1VJRFXcnaRIYAAABXAAAAfyEAAFwMAADlAAAAsjtiBbBHcAFRHGIFTkJwATMAnwoayG8z
                distance:
                  type: number
                  description: >-
                    The distance of travel from the maneuver to the subsequent
                    step, in float meters.
                  example: 830.734383
                name:
                  type: string
                  example: Mouchak - Fulbari Road
                location:
                  type: array
                  items:
                    - type: number
                      example: 90.364394
                    - type: number
                      example: 23.940838
    route_optimization_body:
      type: object
      properties:
        api_key:
          type: string
          description: API_KEY
          example: API_KEY
        source:
          type: string
          description: 23.746086,90.37368.
          example: 23.746086,90.37368
        destination:
          type: string
          description: 23.746214,90.371654.
          example: 23.746214,90.371654
        profile:
          type: string
          description: >
            Default: `car`

            Specifies the vehicle profile of this type. The profile is used to
            determine the network, speed and other physical attributes to use
            for routing the vehicle or pedestrian. Valid profile values `bike`,
            `foot`.
          example: car
        geo_points:
          type: array
          description: array of point elements.
          items:
            properties:
              id:
                type: integer
                example: 1
              point:
                type: string
                example: 23.746086,90.37368
            required:
              - id
              - point
      required:
        - api_key
        - source
        - destination
        - geo_points
    route_optimization_success: &ref_20
      type: object
      properties:
        hints:
          type: object
          properties:
            visited_nodes.sum:
              type: integer
              example: 50
            visited_nodes.average:
              type: integer
              example: 10
        info:
          type: object
          properties:
            copyrights:
              type: array
              items:
                type: string
                example: GraphHopper
            took:
              type: number
              example: 0
        paths:
          type: array
          items:
            type: object
            properties:
              distance:
                type: number
                format: double
                description: The total distance, in meters.
                example: 1846.266
              weight:
                type: number
                format: double
                example: 147.083567
              time:
                type: integer
                format: int64
                description: The total travel time, in milliseconds.
                example: 147071
              transfers:
                type: number
                example: 0
              points_encoded:
                type: boolean
                description: >
                  Whether the `points` and `snapped_waypoints` fields are
                  polyline-encoded strings rather than JSON arrays of
                  coordinates. See the field description for more information on
                  the two formats.
                example: true
              bbox:
                type: array
                items:
                  type: number
                  format: double
                  description: >
                    The bounding box of the route geometry. Format: [minLon,
                    minLat, maxLon, maxLat].
              points:
                type: string
                format: EncodedLineString (string) or LineString (object)
                description: >-
                  The geometry of the route. The format depends on the value of
                  `points_encoded`.
                example: >-
                  c{|oCacrfPh@hA~B~ErCcBrGwD`Bw@rOkGDNyKtEiChAmIxE~@fB_AgB_L~GK[d@Y
              instructions:
                type: array
                items:
                  type: object
                  properties:
                    distance:
                      type: number
                      format: double
                      description: |
                        The distance for this instruction, in meters.
                      example: 0
                    sign:
                      type: integer
                      format: int64
                      description: |
                        A number which specifies the sign to show.
                      example: 5
                    interval:
                      type: array
                      description: >
                        Two indices into `points`, referring to the beginning
                        and the end of the segment of the route this instruction
                        refers to.
                      items:
                        type: integer
                        format: int64
                        example: 0
                    text:
                      type: string
                      description: >
                        A description what the user has to do in order to follow
                        the route. The language depends on the locale parameter.
                      example: Waypoint 1
                    time:
                      type: integer
                      format: int32
                      description: |
                        The duration for this instruction, in milliseconds.
                      example: 0
                    street_name:
                      type: string
                      description: >
                        The name of the street to turn onto in order to follow
                        the route.
                      example: null
              legs:
                type: array
              details:
                type: object
              ascend:
                type: number
                format: double
                description: The total ascent, in meters.
                example: 0
              descend:
                type: number
                format: double
                description: The total descent, in meters.
                example: 0
              snapped_waypoints:
                type: string
                format: EncodedLineString (string) or LineString (object)
                description: >
                  The snapped input points. The format depends on the value of
                  `points_encoded`.
                example: c{|oCacrfP??h@hArGzB|AtBeM`C
    route_location_optimized_body:
      type: object
      properties:
        api_key:
          type: string
          description: API_KEY
          example: api_key
        locations:
          type: array
          items:
            - type: object
              properties:
                point:
                  type: object
                  properties:
                    lat:
                      type: number
                      example: 24.439648
                    lon:
                      type: number
                      example: 90.731277
                  required:
                    - lat
                    - lon
                additional_payload:
                  type: array
                  items:
                    type: object
                    properties:
                      address:
                        type: string
                        example: Kishoreganj Thana
              required:
                - point
            - type: object
              properties:
                point:
                  type: object
                  properties:
                    lat:
                      type: number
                      example: 23.74608583
                    lon:
                      type: number
                      example: 90.37368
                  required:
                    - lat
                    - lon
                additional_payload:
                  type: array
                  items:
                    type: object
                    properties:
                      address:
                        type: string
                        example: House 36, Road 9/A
              required:
                - point
            - type: object
              properties:
                point:
                  type: object
                  properties:
                    lat:
                      type: number
                      example: 24.440899
                    lon:
                      type: number
                      example: 90.771103
                  required:
                    - lat
                    - lon
                additional_payload:
                  type: array
                  items:
                    type: object
                    properties:
                      address:
                        type: string
                        example: Monju Villa, House 1244, Hossainpur Road, Nogua
              required:
                - point
            - type: object
              properties:
                point:
                  type: object
                  properties:
                    lat:
                      type: number
                      example: 23.74577034
                    lon:
                      type: number
                      example: 90.37338898
                  required:
                    - lat
                    - lon
                additional_payload:
                  type: array
                  items:
                    type: object
                    properties:
                      address:
                        type: string
                        example: House 38, Road 9/A
              required:
                - point
            - type: object
              properties:
                point:
                  type: object
                  properties:
                    lat:
                      type: number
                      example: 23.74441997
                    lon:
                      type: number
                      example: 90.37290861
                  required:
                    - lat
                    - lon
                additional_payload:
                  type: array
                  items:
                    type: object
                    properties:
                      address:
                        type: string
                        example: Dhanmondi, Road 8/a
              required:
                - point
      required:
        - api_key
        - locations
    route_location_optimized_success: &ref_21
      type: object
      properties:
        sorted_waypoints:
          type: array
          items:
            - type: object
              properties:
                point:
                  type: object
                  properties:
                    lat:
                      type: number
                      example: 24.439648
                    lon:
                      type: number
                      example: 90.731277
                additional_payload:
                  type: array
                  items:
                    type: object
                    properties:
                      address:
                        type: string
                        example: Kishoreganj Thana
                index:
                  type: integer
                  example: 1
            - type: object
              properties:
                point:
                  type: object
                  properties:
                    lat:
                      type: number
                      example: 24.440899
                    lon:
                      type: number
                      example: 90.771103
                additional_payload:
                  type: array
                  items:
                    type: object
                    properties:
                      address:
                        type: string
                        example: Monju Villa, House 1244, Hossainpur Road, Nogua
                index:
                  type: integer
                  example: 2
            - type: object
              properties:
                point:
                  type: object
                  properties:
                    lat:
                      type: number
                      example: 23.74608583
                    lon:
                      type: number
                      example: 90.37368
                additional_payload:
                  type: array
                  items:
                    type: object
                    properties:
                      address:
                        type: string
                        example: House 36, Road 9/A
                index:
                  type: integer
                  example: 3
            - type: object
              properties:
                point:
                  type: object
                  properties:
                    lat:
                      type: number
                      example: 23.74577034
                    lon:
                      type: number
                      example: 90.37338898
                additional_payload:
                  type: array
                  items:
                    type: object
                    properties:
                      address:
                        type: string
                        example: House 38, Road 9/A
                index:
                  type: integer
                  example: 4
            - type: object
              properties:
                point:
                  type: object
                  properties:
                    lat:
                      type: number
                      example: 23.74441997
                    lon:
                      type: number
                      example: 90.37290861
                additional_payload:
                  type: array
                  items:
                    type: object
                    properties:
                      address:
                        type: string
                        example: Dhanmondi, Road 8/a
                index:
                  type: integer
                  example: 5
        status:
          type: integer
          default: 200
    snap_to_road_success: &ref_9
      type: object
      properties:
        coordinates:
          type: array
          items:
            type: number
            format: double
          example:
            - 90.36288583910802
            - 23.80475086627028
        distance:
          type: number
          format: double
          example: 0.5866113852736488
        type:
          type: string
          example: Point
    route_match_success: &ref_10
      type: object
      properties:
        geometry:
          type: object
          properties:
            coordinates:
              type: array
              items:
                type: array
                items:
                  type: number
                  format: double
              format: array
              example:
                - - 90.384425
                  - 23.726761
                - - 90.384427
                  - 23.726622
            type:
              type: string
              example: LineString
        distance:
          type: number
          format: double
          example: 15.5
        status:
          type: integer
          default: 200
    point_in_polygon_form:
      type: object
      properties:
        point:
          type: string
          description: 90.41697542000593,23.780273491928714
    point_in_polygon_success: &ref_25
      type: object
      properties:
        message:
          type: string
          default: Point not inside polygon
        status:
          type: number
          default: 200
        data:
          type: null
    area_success: &ref_22
      type: object
      properties:
        area:
          type: string
          default: dakkhinkhan
        status:
          type: number
          default: 200
    rev_geo_success-2: *ref_0
    missing_parameter-2: *ref_1
    no_registered_key-2: *ref_2
    payment_exception-2: *ref_3
    api_limit_exceeded-2: *ref_4
    rev_geo_server_success:
      type: object
      properties:
        place:
          type: object
          properties:
            id:
              type: integer
              example: 534001
            distance_within_meters:
              type: number
              example: 3.9083
            address:
              type: string
              example: House 20, Avenue 3, Lane 25, Block D, Section 11
            area:
              type: string
              example: Mirpur
            city:
              type: string
              example: Dhaka
            postCode:
              type: integer
              example: 1216
            country:
              type: string
              example: Bangladesh
            division:
              type: string
              example: Dhaka
            sub_district:
              type: string
              example: Pallabi
            district:
              type: string
              example: Dhaka
            pauroshova:
              type: string
              example: null
            union:
              type: string
              example: null
            location_type:
              type: string
              example: Urban
            address_components:
              type: object
              properties:
                place_name:
                  type: string
                  example: null
                house:
                  type: string
                  example: House 20
                road:
                  type: string
                  example: Avenue 3
            area_components:
              type: object
              properties:
                area:
                  type: string
                  example: Mirpur
                sub_area:
                  type: string
                  example: Section 11
        status:
          type: integer
          default: 200
    autocomplete_success-2: *ref_5
    distance_success:
      type: object
      properties:
        Distance:
          type: string
          default: 0.8081 KM
        status:
          type: integer
          default: 200
    rupantor_geocoder_success-2: *ref_6
    rupantor_address_match_success-2: *ref_7
    routing_success-2: *ref_8
    snap_to_road_success-2: *ref_9
    route_match_success-2: *ref_10
    districts_success-2: *ref_11
    subdistricts_success-2: *ref_12
    cities_success-2: *ref_13
    unions_success-2: *ref_14
    ward_success-2: *ref_15
    zone_success-2: *ref_16
    wardzone_success-2: *ref_17
    dncc_success-2: *ref_18
    autocomplete_bangla_success-2: *ref_19
    route_optimization_success-2: *ref_20
    route_location_optimized_success-2: *ref_21
    area_success-2: *ref_22
    ward_geometry_success-2: *ref_23
    nearby_success-2: *ref_24
    point_in_polygon_success-2: *ref_25
  responses:
    rev_geo_success:
      description: rev_geo_success
      content:
        application/json:
          schema:
            $ref: '#/components/schemas/rev_geo_success-2'
    rev_geo_server_success:
      description: rev_geo_server_success
      content:
        application/json:
          schema:
            $ref: '#/components/schemas/rev_geo_server_success'
    nearby_success:
      description: nearby_success
      content:
        application/json:
          schema:
            $ref: '#/components/schemas/nearby_success-2'
    autocomplete_success:
      description: autocomplete_success
      content:
        application/json:
          schema:
            $ref: '#/components/schemas/autocomplete_success-2'
    autocomplete_bangla_success:
      description: autocomplete_bangla_success
      content:
        application/json:
          schema:
            $ref: '#/components/schemas/autocomplete_bangla_success-2'
    rupantor_geocoder_success:
      description: rupantor_geocoder_success
      content:
        application/json:
          schema:
            $ref: '#/components/schemas/rupantor_geocoder_success-2'
    rupantor_address_match_success:
      description: rupantor_address_match_success
      content:
        application/json:
          schema:
            $ref: '#/components/schemas/rupantor_address_match_success-2'
    routing_success:
      description: routing_success
      content:
        application/json:
          schema:
            $ref: '#/components/schemas/routing_success-2'
    route_optimization_success:
      description: route_optimization_success
      content:
        application/json:
          schema:
            $ref: '#/components/schemas/route_optimization_success-2'
    distance_success:
      description: distance_success
      content:
        application/json:
          schema:
            $ref: '#/components/schemas/distance_success'
    route_location_optimized_success:
      description: route_location_optimized_success
      content:
        application/json:
          schema:
            $ref: '#/components/schemas/route_location_optimized_success-2'
    snap_to_road_success:
      $ref: '#/components/responses/span_to_road_success'
    route_match_success:
      description: route_match_success
      content:
        application/json:
          schema:
            $ref: '#/components/schemas/route_match_success-2'
    api_limit_exceeded:
      description: api_limit_exceeded
      content:
        application/json:
          schema:
            $ref: '#/components/schemas/api_limit_exceeded-2'
    no_registered_key:
      description: no_registered_key
      content:
        application/json:
          schema:
            $ref: '#/components/schemas/no_registered_key-2'
    missing_parameter:
      description: missing_parameter
      content:
        application/json:
          schema:
            $ref: '#/components/schemas/missing_parameter-2'
    payment_exception:
      description: payment_exception
      content:
        application/json:
          schema:
            $ref: '#/components/schemas/payment_exception-2'
    dncc_success:
      description: dncc_success
      content:
        application/json:
          schema:
            $ref: '#/components/schemas/dncc_success-2'
    wardzone_success:
      description: wardzone_success
      content:
        application/json:
          schema:
            $ref: '#/components/schemas/wardzone_success-2'
    ward_geometry_success:
      description: ward_geometry_success
      content:
        application/json:
          schema:
            $ref: '#/components/schemas/ward_geometry_success-2'
    unions_success:
      description: unions_success
      content:
        application/json:
          schema:
            $ref: '#/components/schemas/unions_success-2'
    cities_success:
      description: cities_success
      content:
        application/json:
          schema:
            $ref: '#/components/schemas/cities_success-2'
    ward_success:
      description: ward_success
      content:
        application/json:
          schema:
            $ref: '#/components/schemas/ward_success-2'
    zone_success:
      description: zone_success
      content:
        application/json:
          schema:
            $ref: '#/components/schemas/zone_success-2'
    subdistricts_success:
      description: subdistricts_success
      content:
        application/json:
          schema:
            $ref: '#/components/schemas/subdistricts_success-2'
    districts_success:
      description: districts_success
      content:
        application/json:
          schema:
            $ref: '#/components/schemas/districts_success-2'
    point_in_polygon_success:
      description: point_in_polygon_success
      content:
        application/json:
          schema:
            $ref: '#/components/schemas/point_in_polygon_success-2'
    area_success:
      description: area_success
      content:
        application/json:
          schema:
            $ref: '#/components/schemas/area_success-2'
    span_to_road_success:
      description: snap_to_road_success
      content:
        application/json:
          schema:
            $ref: '#/components/schemas/snap_to_road_success-2'
